# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Dict, List, Mapping, Optional, Tuple, Union
from .. import _utilities, _tables

__all__ = [
    'FunctionEventTriggerArgs',
    'FunctionEventTriggerFailurePolicyArgs',
    'FunctionIamBindingConditionArgs',
    'FunctionIamMemberConditionArgs',
    'FunctionSourceRepositoryArgs',
]

@pulumi.input_type
class FunctionEventTriggerArgs:
    def __init__(__self__, *,
                 event_type: pulumi.Input[str],
                 resource: pulumi.Input[str],
                 failure_policy: Optional[pulumi.Input['FunctionEventTriggerFailurePolicyArgs']] = None):
        """
        :param pulumi.Input[str] event_type: The type of event to observe. For example: `"google.storage.object.finalize"`.
               See the documentation on [calling Cloud Functions](https://cloud.google.com/functions/docs/calling/) for a
               full reference of accepted triggers.
        :param pulumi.Input[str] resource: Required. The name or partial URI of the resource from
               which to observe events. For example, `"myBucket"` or `"projects/my-project/topics/my-topic"`
        :param pulumi.Input['FunctionEventTriggerFailurePolicyArgs'] failure_policy: Specifies policy for failed executions. Structure is documented below.
        """
        pulumi.set(__self__, "event_type", event_type)
        pulumi.set(__self__, "resource", resource)
        if failure_policy is not None:
            pulumi.set(__self__, "failure_policy", failure_policy)

    @property
    @pulumi.getter(name="eventType")
    def event_type(self) -> pulumi.Input[str]:
        """
        The type of event to observe. For example: `"google.storage.object.finalize"`.
        See the documentation on [calling Cloud Functions](https://cloud.google.com/functions/docs/calling/) for a
        full reference of accepted triggers.
        """
        return pulumi.get(self, "event_type")

    @event_type.setter
    def event_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "event_type", value)

    @property
    @pulumi.getter
    def resource(self) -> pulumi.Input[str]:
        """
        Required. The name or partial URI of the resource from
        which to observe events. For example, `"myBucket"` or `"projects/my-project/topics/my-topic"`
        """
        return pulumi.get(self, "resource")

    @resource.setter
    def resource(self, value: pulumi.Input[str]):
        pulumi.set(self, "resource", value)

    @property
    @pulumi.getter(name="failurePolicy")
    def failure_policy(self) -> Optional[pulumi.Input['FunctionEventTriggerFailurePolicyArgs']]:
        """
        Specifies policy for failed executions. Structure is documented below.
        """
        return pulumi.get(self, "failure_policy")

    @failure_policy.setter
    def failure_policy(self, value: Optional[pulumi.Input['FunctionEventTriggerFailurePolicyArgs']]):
        pulumi.set(self, "failure_policy", value)


@pulumi.input_type
class FunctionEventTriggerFailurePolicyArgs:
    def __init__(__self__, *,
                 retry: pulumi.Input[bool]):
        """
        :param pulumi.Input[bool] retry: Whether the function should be retried on failure. Defaults to `false`.
        """
        pulumi.set(__self__, "retry", retry)

    @property
    @pulumi.getter
    def retry(self) -> pulumi.Input[bool]:
        """
        Whether the function should be retried on failure. Defaults to `false`.
        """
        return pulumi.get(self, "retry")

    @retry.setter
    def retry(self, value: pulumi.Input[bool]):
        pulumi.set(self, "retry", value)


@pulumi.input_type
class FunctionIamBindingConditionArgs:
    def __init__(__self__, *,
                 expression: pulumi.Input[str],
                 title: pulumi.Input[str],
                 description: Optional[pulumi.Input[str]] = None):
        pulumi.set(__self__, "expression", expression)
        pulumi.set(__self__, "title", title)
        if description is not None:
            pulumi.set(__self__, "description", description)

    @property
    @pulumi.getter
    def expression(self) -> pulumi.Input[str]:
        return pulumi.get(self, "expression")

    @expression.setter
    def expression(self, value: pulumi.Input[str]):
        pulumi.set(self, "expression", value)

    @property
    @pulumi.getter
    def title(self) -> pulumi.Input[str]:
        return pulumi.get(self, "title")

    @title.setter
    def title(self, value: pulumi.Input[str]):
        pulumi.set(self, "title", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)


@pulumi.input_type
class FunctionIamMemberConditionArgs:
    def __init__(__self__, *,
                 expression: pulumi.Input[str],
                 title: pulumi.Input[str],
                 description: Optional[pulumi.Input[str]] = None):
        pulumi.set(__self__, "expression", expression)
        pulumi.set(__self__, "title", title)
        if description is not None:
            pulumi.set(__self__, "description", description)

    @property
    @pulumi.getter
    def expression(self) -> pulumi.Input[str]:
        return pulumi.get(self, "expression")

    @expression.setter
    def expression(self, value: pulumi.Input[str]):
        pulumi.set(self, "expression", value)

    @property
    @pulumi.getter
    def title(self) -> pulumi.Input[str]:
        return pulumi.get(self, "title")

    @title.setter
    def title(self, value: pulumi.Input[str]):
        pulumi.set(self, "title", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)


@pulumi.input_type
class FunctionSourceRepositoryArgs:
    def __init__(__self__, *,
                 url: pulumi.Input[str],
                 deployed_url: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] url: The URL pointing to the hosted repository where the function is defined. There are supported Cloud Source Repository URLs in the following formats:
        """
        pulumi.set(__self__, "url", url)
        if deployed_url is not None:
            pulumi.set(__self__, "deployed_url", deployed_url)

    @property
    @pulumi.getter
    def url(self) -> pulumi.Input[str]:
        """
        The URL pointing to the hosted repository where the function is defined. There are supported Cloud Source Repository URLs in the following formats:
        """
        return pulumi.get(self, "url")

    @url.setter
    def url(self, value: pulumi.Input[str]):
        pulumi.set(self, "url", value)

    @property
    @pulumi.getter(name="deployedUrl")
    def deployed_url(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "deployed_url")

    @deployed_url.setter
    def deployed_url(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "deployed_url", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Dict, List, Mapping, Optional, Tuple, Union
from .. import _utilities, _tables
from . import outputs
from ._inputs import *

__all__ = ['Job']


class Job(pulumi.CustomResource):
    def __init__(__self__,
                 resource_name,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 force_delete: Optional[pulumi.Input[bool]] = None,
                 hadoop_config: Optional[pulumi.Input[pulumi.InputType['JobHadoopConfigArgs']]] = None,
                 hive_config: Optional[pulumi.Input[pulumi.InputType['JobHiveConfigArgs']]] = None,
                 labels: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 pig_config: Optional[pulumi.Input[pulumi.InputType['JobPigConfigArgs']]] = None,
                 placement: Optional[pulumi.Input[pulumi.InputType['JobPlacementArgs']]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 pyspark_config: Optional[pulumi.Input[pulumi.InputType['JobPysparkConfigArgs']]] = None,
                 reference: Optional[pulumi.Input[pulumi.InputType['JobReferenceArgs']]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 scheduling: Optional[pulumi.Input[pulumi.InputType['JobSchedulingArgs']]] = None,
                 spark_config: Optional[pulumi.Input[pulumi.InputType['JobSparkConfigArgs']]] = None,
                 sparksql_config: Optional[pulumi.Input[pulumi.InputType['JobSparksqlConfigArgs']]] = None,
                 __props__=None,
                 __name__=None,
                 __opts__=None):
        """
        Manages a job resource within a Dataproc cluster within GCE. For more information see
        [the official dataproc documentation](https://cloud.google.com/dataproc/).

        !> **Note:** This resource does not support 'update' and changing any attributes will cause the resource to be recreated.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] force_delete: By default, you can only delete inactive jobs within
               Dataproc. Setting this to true, and calling destroy, will ensure that the
               job is first cancelled before issuing the delete.
        :param pulumi.Input[pulumi.InputType['JobHadoopConfigArgs']] hadoop_config: The config of Hadoop job
        :param pulumi.Input[pulumi.InputType['JobHiveConfigArgs']] hive_config: The config of hive job
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] labels: The list of labels (key/value pairs) to add to the job.
        :param pulumi.Input[pulumi.InputType['JobPigConfigArgs']] pig_config: The config of pag job.
        :param pulumi.Input[pulumi.InputType['JobPlacementArgs']] placement: The config of job placement.
        :param pulumi.Input[str] project: The project in which the `cluster` can be found and jobs
               subsequently run against. If it is not provided, the provider project is used.
        :param pulumi.Input[pulumi.InputType['JobPysparkConfigArgs']] pyspark_config: The config of pySpark job.
        :param pulumi.Input[pulumi.InputType['JobReferenceArgs']] reference: The reference of the job
        :param pulumi.Input[str] region: The Cloud Dataproc region. This essentially determines which clusters are available
               for this job to be submitted to. If not specified, defaults to `global`.
        :param pulumi.Input[pulumi.InputType['JobSchedulingArgs']] scheduling: Optional. Job scheduling configuration.
        :param pulumi.Input[pulumi.InputType['JobSparkConfigArgs']] spark_config: The config of the Spark job.
        :param pulumi.Input[pulumi.InputType['JobSparksqlConfigArgs']] sparksql_config: The config of SparkSql job
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = _utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['force_delete'] = force_delete
            __props__['hadoop_config'] = hadoop_config
            __props__['hive_config'] = hive_config
            __props__['labels'] = labels
            __props__['pig_config'] = pig_config
            if placement is None:
                raise TypeError("Missing required property 'placement'")
            __props__['placement'] = placement
            __props__['project'] = project
            __props__['pyspark_config'] = pyspark_config
            __props__['reference'] = reference
            __props__['region'] = region
            __props__['scheduling'] = scheduling
            __props__['spark_config'] = spark_config
            __props__['sparksql_config'] = sparksql_config
            __props__['driver_controls_files_uri'] = None
            __props__['driver_output_resource_uri'] = None
            __props__['status'] = None
        super(Job, __self__).__init__(
            'gcp:dataproc/job:Job',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            driver_controls_files_uri: Optional[pulumi.Input[str]] = None,
            driver_output_resource_uri: Optional[pulumi.Input[str]] = None,
            force_delete: Optional[pulumi.Input[bool]] = None,
            hadoop_config: Optional[pulumi.Input[pulumi.InputType['JobHadoopConfigArgs']]] = None,
            hive_config: Optional[pulumi.Input[pulumi.InputType['JobHiveConfigArgs']]] = None,
            labels: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            pig_config: Optional[pulumi.Input[pulumi.InputType['JobPigConfigArgs']]] = None,
            placement: Optional[pulumi.Input[pulumi.InputType['JobPlacementArgs']]] = None,
            project: Optional[pulumi.Input[str]] = None,
            pyspark_config: Optional[pulumi.Input[pulumi.InputType['JobPysparkConfigArgs']]] = None,
            reference: Optional[pulumi.Input[pulumi.InputType['JobReferenceArgs']]] = None,
            region: Optional[pulumi.Input[str]] = None,
            scheduling: Optional[pulumi.Input[pulumi.InputType['JobSchedulingArgs']]] = None,
            spark_config: Optional[pulumi.Input[pulumi.InputType['JobSparkConfigArgs']]] = None,
            sparksql_config: Optional[pulumi.Input[pulumi.InputType['JobSparksqlConfigArgs']]] = None,
            status: Optional[pulumi.Input[pulumi.InputType['JobStatusArgs']]] = None) -> 'Job':
        """
        Get an existing Job resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] driver_controls_files_uri: If present, the location of miscellaneous control files which may be used as part of job setup and handling. If not present, control files may be placed in the same location as driver_output_uri.
        :param pulumi.Input[str] driver_output_resource_uri: A URI pointing to the location of the stdout of the job's driver program.
        :param pulumi.Input[bool] force_delete: By default, you can only delete inactive jobs within
               Dataproc. Setting this to true, and calling destroy, will ensure that the
               job is first cancelled before issuing the delete.
        :param pulumi.Input[pulumi.InputType['JobHadoopConfigArgs']] hadoop_config: The config of Hadoop job
        :param pulumi.Input[pulumi.InputType['JobHiveConfigArgs']] hive_config: The config of hive job
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] labels: The list of labels (key/value pairs) to add to the job.
        :param pulumi.Input[pulumi.InputType['JobPigConfigArgs']] pig_config: The config of pag job.
        :param pulumi.Input[pulumi.InputType['JobPlacementArgs']] placement: The config of job placement.
        :param pulumi.Input[str] project: The project in which the `cluster` can be found and jobs
               subsequently run against. If it is not provided, the provider project is used.
        :param pulumi.Input[pulumi.InputType['JobPysparkConfigArgs']] pyspark_config: The config of pySpark job.
        :param pulumi.Input[pulumi.InputType['JobReferenceArgs']] reference: The reference of the job
        :param pulumi.Input[str] region: The Cloud Dataproc region. This essentially determines which clusters are available
               for this job to be submitted to. If not specified, defaults to `global`.
        :param pulumi.Input[pulumi.InputType['JobSchedulingArgs']] scheduling: Optional. Job scheduling configuration.
        :param pulumi.Input[pulumi.InputType['JobSparkConfigArgs']] spark_config: The config of the Spark job.
        :param pulumi.Input[pulumi.InputType['JobSparksqlConfigArgs']] sparksql_config: The config of SparkSql job
        :param pulumi.Input[pulumi.InputType['JobStatusArgs']] status: The status of the job.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["driver_controls_files_uri"] = driver_controls_files_uri
        __props__["driver_output_resource_uri"] = driver_output_resource_uri
        __props__["force_delete"] = force_delete
        __props__["hadoop_config"] = hadoop_config
        __props__["hive_config"] = hive_config
        __props__["labels"] = labels
        __props__["pig_config"] = pig_config
        __props__["placement"] = placement
        __props__["project"] = project
        __props__["pyspark_config"] = pyspark_config
        __props__["reference"] = reference
        __props__["region"] = region
        __props__["scheduling"] = scheduling
        __props__["spark_config"] = spark_config
        __props__["sparksql_config"] = sparksql_config
        __props__["status"] = status
        return Job(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="driverControlsFilesUri")
    def driver_controls_files_uri(self) -> str:
        """
        If present, the location of miscellaneous control files which may be used as part of job setup and handling. If not present, control files may be placed in the same location as driver_output_uri.
        """
        return pulumi.get(self, "driver_controls_files_uri")

    @property
    @pulumi.getter(name="driverOutputResourceUri")
    def driver_output_resource_uri(self) -> str:
        """
        A URI pointing to the location of the stdout of the job's driver program.
        """
        return pulumi.get(self, "driver_output_resource_uri")

    @property
    @pulumi.getter(name="forceDelete")
    def force_delete(self) -> Optional[bool]:
        """
        By default, you can only delete inactive jobs within
        Dataproc. Setting this to true, and calling destroy, will ensure that the
        job is first cancelled before issuing the delete.
        """
        return pulumi.get(self, "force_delete")

    @property
    @pulumi.getter(name="hadoopConfig")
    def hadoop_config(self) -> Optional['outputs.JobHadoopConfig']:
        """
        The config of Hadoop job
        """
        return pulumi.get(self, "hadoop_config")

    @property
    @pulumi.getter(name="hiveConfig")
    def hive_config(self) -> Optional['outputs.JobHiveConfig']:
        """
        The config of hive job
        """
        return pulumi.get(self, "hive_config")

    @property
    @pulumi.getter
    def labels(self) -> Optional[Mapping[str, str]]:
        """
        The list of labels (key/value pairs) to add to the job.
        """
        return pulumi.get(self, "labels")

    @property
    @pulumi.getter(name="pigConfig")
    def pig_config(self) -> Optional['outputs.JobPigConfig']:
        """
        The config of pag job.
        """
        return pulumi.get(self, "pig_config")

    @property
    @pulumi.getter
    def placement(self) -> 'outputs.JobPlacement':
        """
        The config of job placement.
        """
        return pulumi.get(self, "placement")

    @property
    @pulumi.getter
    def project(self) -> str:
        """
        The project in which the `cluster` can be found and jobs
        subsequently run against. If it is not provided, the provider project is used.
        """
        return pulumi.get(self, "project")

    @property
    @pulumi.getter(name="pysparkConfig")
    def pyspark_config(self) -> Optional['outputs.JobPysparkConfig']:
        """
        The config of pySpark job.
        """
        return pulumi.get(self, "pyspark_config")

    @property
    @pulumi.getter
    def reference(self) -> 'outputs.JobReference':
        """
        The reference of the job
        """
        return pulumi.get(self, "reference")

    @property
    @pulumi.getter
    def region(self) -> Optional[str]:
        """
        The Cloud Dataproc region. This essentially determines which clusters are available
        for this job to be submitted to. If not specified, defaults to `global`.
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter
    def scheduling(self) -> Optional['outputs.JobScheduling']:
        """
        Optional. Job scheduling configuration.
        """
        return pulumi.get(self, "scheduling")

    @property
    @pulumi.getter(name="sparkConfig")
    def spark_config(self) -> Optional['outputs.JobSparkConfig']:
        """
        The config of the Spark job.
        """
        return pulumi.get(self, "spark_config")

    @property
    @pulumi.getter(name="sparksqlConfig")
    def sparksql_config(self) -> Optional['outputs.JobSparksqlConfig']:
        """
        The config of SparkSql job
        """
        return pulumi.get(self, "sparksql_config")

    @property
    @pulumi.getter
    def status(self) -> 'outputs.JobStatus':
        """
        The status of the job.
        """
        return pulumi.get(self, "status")

    def translate_output_property(self, prop):
        return _tables.CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return _tables.SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Dict, List, Mapping, Optional, Tuple, Union
from .. import _utilities, _tables

__all__ = ['TargetPool']


class TargetPool(pulumi.CustomResource):
    def __init__(__self__,
                 resource_name,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 backup_pool: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 failover_ratio: Optional[pulumi.Input[float]] = None,
                 health_checks: Optional[pulumi.Input[str]] = None,
                 instances: Optional[pulumi.Input[List[pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 session_affinity: Optional[pulumi.Input[str]] = None,
                 __props__=None,
                 __name__=None,
                 __opts__=None):
        """
        Manages a Target Pool within GCE. This is a collection of instances used as
        target of a network load balancer (Forwarding Rule). For more information see
        [the official
        documentation](https://cloud.google.com/compute/docs/load-balancing/network/target-pools)
        and [API](https://cloud.google.com/compute/docs/reference/latest/targetPools).

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] backup_pool: URL to the backup target pool. Must also set
               failover\_ratio.
        :param pulumi.Input[str] description: Textual description field.
        :param pulumi.Input[float] failover_ratio: Ratio (0 to 1) of failed nodes before using the
               backup pool (which must also be set).
        :param pulumi.Input[str] health_checks: List of zero or one health check name or self_link. Only
               legacy `compute.HttpHealthCheck` is supported.
        :param pulumi.Input[List[pulumi.Input[str]]] instances: List of instances in the pool. They can be given as
               URLs, or in the form of "zone/name". Note that the instances need not exist
               at the time of target pool creation, so there is no need to use the
               interpolation to create a dependency on the instances from the
               target pool.
        :param pulumi.Input[str] name: A unique name for the resource, required by GCE. Changing
               this forces a new resource to be created.
        :param pulumi.Input[str] project: The ID of the project in which the resource belongs. If it
               is not provided, the provider project is used.
        :param pulumi.Input[str] region: Where the target pool resides. Defaults to project
               region.
        :param pulumi.Input[str] session_affinity: How to distribute load. Options are "NONE" (no
               affinity). "CLIENT\_IP" (hash of the source/dest addresses / ports), and
               "CLIENT\_IP\_PROTO" also includes the protocol (default "NONE").
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = _utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['backup_pool'] = backup_pool
            __props__['description'] = description
            __props__['failover_ratio'] = failover_ratio
            __props__['health_checks'] = health_checks
            __props__['instances'] = instances
            __props__['name'] = name
            __props__['project'] = project
            __props__['region'] = region
            __props__['session_affinity'] = session_affinity
            __props__['self_link'] = None
        super(TargetPool, __self__).__init__(
            'gcp:compute/targetPool:TargetPool',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            backup_pool: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            failover_ratio: Optional[pulumi.Input[float]] = None,
            health_checks: Optional[pulumi.Input[str]] = None,
            instances: Optional[pulumi.Input[List[pulumi.Input[str]]]] = None,
            name: Optional[pulumi.Input[str]] = None,
            project: Optional[pulumi.Input[str]] = None,
            region: Optional[pulumi.Input[str]] = None,
            self_link: Optional[pulumi.Input[str]] = None,
            session_affinity: Optional[pulumi.Input[str]] = None) -> 'TargetPool':
        """
        Get an existing TargetPool resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] backup_pool: URL to the backup target pool. Must also set
               failover\_ratio.
        :param pulumi.Input[str] description: Textual description field.
        :param pulumi.Input[float] failover_ratio: Ratio (0 to 1) of failed nodes before using the
               backup pool (which must also be set).
        :param pulumi.Input[str] health_checks: List of zero or one health check name or self_link. Only
               legacy `compute.HttpHealthCheck` is supported.
        :param pulumi.Input[List[pulumi.Input[str]]] instances: List of instances in the pool. They can be given as
               URLs, or in the form of "zone/name". Note that the instances need not exist
               at the time of target pool creation, so there is no need to use the
               interpolation to create a dependency on the instances from the
               target pool.
        :param pulumi.Input[str] name: A unique name for the resource, required by GCE. Changing
               this forces a new resource to be created.
        :param pulumi.Input[str] project: The ID of the project in which the resource belongs. If it
               is not provided, the provider project is used.
        :param pulumi.Input[str] region: Where the target pool resides. Defaults to project
               region.
        :param pulumi.Input[str] self_link: The URI of the created resource.
        :param pulumi.Input[str] session_affinity: How to distribute load. Options are "NONE" (no
               affinity). "CLIENT\_IP" (hash of the source/dest addresses / ports), and
               "CLIENT\_IP\_PROTO" also includes the protocol (default "NONE").
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["backup_pool"] = backup_pool
        __props__["description"] = description
        __props__["failover_ratio"] = failover_ratio
        __props__["health_checks"] = health_checks
        __props__["instances"] = instances
        __props__["name"] = name
        __props__["project"] = project
        __props__["region"] = region
        __props__["self_link"] = self_link
        __props__["session_affinity"] = session_affinity
        return TargetPool(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="backupPool")
    def backup_pool(self) -> Optional[str]:
        """
        URL to the backup target pool. Must also set
        failover\_ratio.
        """
        return pulumi.get(self, "backup_pool")

    @property
    @pulumi.getter
    def description(self) -> Optional[str]:
        """
        Textual description field.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="failoverRatio")
    def failover_ratio(self) -> Optional[float]:
        """
        Ratio (0 to 1) of failed nodes before using the
        backup pool (which must also be set).
        """
        return pulumi.get(self, "failover_ratio")

    @property
    @pulumi.getter(name="healthChecks")
    def health_checks(self) -> Optional[str]:
        """
        List of zero or one health check name or self_link. Only
        legacy `compute.HttpHealthCheck` is supported.
        """
        return pulumi.get(self, "health_checks")

    @property
    @pulumi.getter
    def instances(self) -> List[str]:
        """
        List of instances in the pool. They can be given as
        URLs, or in the form of "zone/name". Note that the instances need not exist
        at the time of target pool creation, so there is no need to use the
        interpolation to create a dependency on the instances from the
        target pool.
        """
        return pulumi.get(self, "instances")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        A unique name for the resource, required by GCE. Changing
        this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def project(self) -> str:
        """
        The ID of the project in which the resource belongs. If it
        is not provided, the provider project is used.
        """
        return pulumi.get(self, "project")

    @property
    @pulumi.getter
    def region(self) -> str:
        """
        Where the target pool resides. Defaults to project
        region.
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter(name="selfLink")
    def self_link(self) -> str:
        """
        The URI of the created resource.
        """
        return pulumi.get(self, "self_link")

    @property
    @pulumi.getter(name="sessionAffinity")
    def session_affinity(self) -> Optional[str]:
        """
        How to distribute load. Options are "NONE" (no
        affinity). "CLIENT\_IP" (hash of the source/dest addresses / ports), and
        "CLIENT\_IP\_PROTO" also includes the protocol (default "NONE").
        """
        return pulumi.get(self, "session_affinity")

    def translate_output_property(self, prop):
        return _tables.CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return _tables.SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Dict, List, Mapping, Optional, Tuple, Union
from .. import _utilities, _tables
from . import outputs
from ._inputs import *

__all__ = ['Registry']

warnings.warn("gcp.kms.Registry has been deprecated in favor of gcp.iot.Registry", DeprecationWarning)


class Registry(pulumi.CustomResource):
    warnings.warn("gcp.kms.Registry has been deprecated in favor of gcp.iot.Registry", DeprecationWarning)

    def __init__(__self__,
                 resource_name,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 credentials: Optional[pulumi.Input[List[pulumi.Input[pulumi.InputType['RegistryCredentialArgs']]]]] = None,
                 event_notification_configs: Optional[pulumi.Input[List[pulumi.Input[pulumi.InputType['RegistryEventNotificationConfigItemArgs']]]]] = None,
                 http_config: Optional[pulumi.Input[pulumi.InputType['RegistryHttpConfigArgs']]] = None,
                 log_level: Optional[pulumi.Input[str]] = None,
                 mqtt_config: Optional[pulumi.Input[pulumi.InputType['RegistryMqttConfigArgs']]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 state_notification_config: Optional[pulumi.Input[pulumi.InputType['RegistryStateNotificationConfigArgs']]] = None,
                 __props__=None,
                 __name__=None,
                 __opts__=None):
        """
        A Google Cloud IoT Core device registry.

        To get more information about DeviceRegistry, see:

        * [API documentation](https://cloud.google.com/iot/docs/reference/cloudiot/rest/)
        * How-to Guides
            * [Official Documentation](https://cloud.google.com/iot/docs/)

        ## Example Usage

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[List[pulumi.Input[pulumi.InputType['RegistryCredentialArgs']]]] credentials: List of public key certificates to authenticate devices.
               The structure is documented below.
        :param pulumi.Input[List[pulumi.Input[pulumi.InputType['RegistryEventNotificationConfigItemArgs']]]] event_notification_configs: List of configurations for event notifications, such as PubSub topics
               to publish device events to.
               Structure is documented below.
        :param pulumi.Input[pulumi.InputType['RegistryHttpConfigArgs']] http_config: Activate or deactivate HTTP.
               The structure is documented below.
        :param pulumi.Input[str] log_level: The default logging verbosity for activity from devices in this
               registry. Specifies which events should be written to logs. For
               example, if the LogLevel is ERROR, only events that terminate in
               errors will be logged. LogLevel is inclusive; enabling INFO logging
               will also enable ERROR logging.
               Default value is `NONE`.
               Possible values are `NONE`, `ERROR`, `INFO`, and `DEBUG`.
        :param pulumi.Input[pulumi.InputType['RegistryMqttConfigArgs']] mqtt_config: Activate or deactivate MQTT.
               The structure is documented below.
        :param pulumi.Input[str] name: A unique name for the resource, required by device registry.
        :param pulumi.Input[str] project: The ID of the project in which the resource belongs.
               If it is not provided, the provider project is used.
        :param pulumi.Input[str] region: The region in which the created registry should reside.
               If it is not provided, the provider region is used.
        :param pulumi.Input[pulumi.InputType['RegistryStateNotificationConfigArgs']] state_notification_config: A PubSub topic to publish device state updates.
               The structure is documented below.
        """
        pulumi.log.warn("Registry is deprecated: gcp.kms.Registry has been deprecated in favor of gcp.iot.Registry")
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = _utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['credentials'] = credentials
            __props__['event_notification_configs'] = event_notification_configs
            __props__['http_config'] = http_config
            __props__['log_level'] = log_level
            __props__['mqtt_config'] = mqtt_config
            __props__['name'] = name
            __props__['project'] = project
            __props__['region'] = region
            __props__['state_notification_config'] = state_notification_config
        super(Registry, __self__).__init__(
            'gcp:kms/registry:Registry',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            credentials: Optional[pulumi.Input[List[pulumi.Input[pulumi.InputType['RegistryCredentialArgs']]]]] = None,
            event_notification_configs: Optional[pulumi.Input[List[pulumi.Input[pulumi.InputType['RegistryEventNotificationConfigItemArgs']]]]] = None,
            http_config: Optional[pulumi.Input[pulumi.InputType['RegistryHttpConfigArgs']]] = None,
            log_level: Optional[pulumi.Input[str]] = None,
            mqtt_config: Optional[pulumi.Input[pulumi.InputType['RegistryMqttConfigArgs']]] = None,
            name: Optional[pulumi.Input[str]] = None,
            project: Optional[pulumi.Input[str]] = None,
            region: Optional[pulumi.Input[str]] = None,
            state_notification_config: Optional[pulumi.Input[pulumi.InputType['RegistryStateNotificationConfigArgs']]] = None) -> 'Registry':
        """
        Get an existing Registry resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[List[pulumi.Input[pulumi.InputType['RegistryCredentialArgs']]]] credentials: List of public key certificates to authenticate devices.
               The structure is documented below.
        :param pulumi.Input[List[pulumi.Input[pulumi.InputType['RegistryEventNotificationConfigItemArgs']]]] event_notification_configs: List of configurations for event notifications, such as PubSub topics
               to publish device events to.
               Structure is documented below.
        :param pulumi.Input[pulumi.InputType['RegistryHttpConfigArgs']] http_config: Activate or deactivate HTTP.
               The structure is documented below.
        :param pulumi.Input[str] log_level: The default logging verbosity for activity from devices in this
               registry. Specifies which events should be written to logs. For
               example, if the LogLevel is ERROR, only events that terminate in
               errors will be logged. LogLevel is inclusive; enabling INFO logging
               will also enable ERROR logging.
               Default value is `NONE`.
               Possible values are `NONE`, `ERROR`, `INFO`, and `DEBUG`.
        :param pulumi.Input[pulumi.InputType['RegistryMqttConfigArgs']] mqtt_config: Activate or deactivate MQTT.
               The structure is documented below.
        :param pulumi.Input[str] name: A unique name for the resource, required by device registry.
        :param pulumi.Input[str] project: The ID of the project in which the resource belongs.
               If it is not provided, the provider project is used.
        :param pulumi.Input[str] region: The region in which the created registry should reside.
               If it is not provided, the provider region is used.
        :param pulumi.Input[pulumi.InputType['RegistryStateNotificationConfigArgs']] state_notification_config: A PubSub topic to publish device state updates.
               The structure is documented below.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["credentials"] = credentials
        __props__["event_notification_configs"] = event_notification_configs
        __props__["http_config"] = http_config
        __props__["log_level"] = log_level
        __props__["mqtt_config"] = mqtt_config
        __props__["name"] = name
        __props__["project"] = project
        __props__["region"] = region
        __props__["state_notification_config"] = state_notification_config
        return Registry(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def credentials(self) -> Optional[List['outputs.RegistryCredential']]:
        """
        List of public key certificates to authenticate devices.
        The structure is documented below.
        """
        return pulumi.get(self, "credentials")

    @property
    @pulumi.getter(name="eventNotificationConfigs")
    def event_notification_configs(self) -> List['outputs.RegistryEventNotificationConfigItem']:
        """
        List of configurations for event notifications, such as PubSub topics
        to publish device events to.
        Structure is documented below.
        """
        return pulumi.get(self, "event_notification_configs")

    @property
    @pulumi.getter(name="httpConfig")
    def http_config(self) -> 'outputs.RegistryHttpConfig':
        """
        Activate or deactivate HTTP.
        The structure is documented below.
        """
        return pulumi.get(self, "http_config")

    @property
    @pulumi.getter(name="logLevel")
    def log_level(self) -> Optional[str]:
        """
        The default logging verbosity for activity from devices in this
        registry. Specifies which events should be written to logs. For
        example, if the LogLevel is ERROR, only events that terminate in
        errors will be logged. LogLevel is inclusive; enabling INFO logging
        will also enable ERROR logging.
        Default value is `NONE`.
        Possible values are `NONE`, `ERROR`, `INFO`, and `DEBUG`.
        """
        return pulumi.get(self, "log_level")

    @property
    @pulumi.getter(name="mqttConfig")
    def mqtt_config(self) -> 'outputs.RegistryMqttConfig':
        """
        Activate or deactivate MQTT.
        The structure is documented below.
        """
        return pulumi.get(self, "mqtt_config")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        A unique name for the resource, required by device registry.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def project(self) -> str:
        """
        The ID of the project in which the resource belongs.
        If it is not provided, the provider project is used.
        """
        return pulumi.get(self, "project")

    @property
    @pulumi.getter
    def region(self) -> str:
        """
        The region in which the created registry should reside.
        If it is not provided, the provider region is used.
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter(name="stateNotificationConfig")
    def state_notification_config(self) -> Optional['outputs.RegistryStateNotificationConfig']:
        """
        A PubSub topic to publish device state updates.
        The structure is documented below.
        """
        return pulumi.get(self, "state_notification_config")

    def translate_output_property(self, prop):
        return _tables.CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return _tables.SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

SNAKE_TO_CAMEL_CASE_TABLE = {
    "accelerator_config": "acceleratorConfig",
    "accelerator_type": "acceleratorType",
    "access_context_manager_custom_endpoint": "accessContextManagerCustomEndpoint",
    "access_id": "accessId",
    "access_token": "accessToken",
    "account_id": "accountId",
    "ack_deadline_seconds": "ackDeadlineSeconds",
    "active_directory_custom_endpoint": "activeDirectoryCustomEndpoint",
    "additional_authenticated_data": "additionalAuthenticatedData",
    "additional_experiments": "additionalExperiments",
    "addons_config": "addonsConfig",
    "address_type": "addressType",
    "admin_enabled": "adminEnabled",
    "admission_whitelist_patterns": "admissionWhitelistPatterns",
    "advertise_mode": "advertiseMode",
    "advertised_groups": "advertisedGroups",
    "advertised_ip_ranges": "advertisedIpRanges",
    "advertised_route_priority": "advertisedRoutePriority",
    "affinity_cookie_ttl_sec": "affinityCookieTtlSec",
    "all_ports": "allPorts",
    "all_updates_rule": "allUpdatesRule",
    "allow_global_access": "allowGlobalAccess",
    "allow_password_signup": "allowPasswordSignup",
    "allow_stopping_for_update": "allowStoppingForUpdate",
    "alternative_location_id": "alternativeLocationId",
    "alternative_name_server_config": "alternativeNameServerConfig",
    "api_config": "apiConfig",
    "api_version": "apiVersion",
    "app_engine": "appEngine",
    "app_engine_custom_endpoint": "appEngineCustomEndpoint",
    "app_engine_http_target": "appEngineHttpTarget",
    "app_engine_routing_override": "appEngineRoutingOverride",
    "app_id": "appId",
    "app_profile_id": "appProfileId",
    "application_title": "applicationTitle",
    "archive_size_bytes": "archiveSizeBytes",
    "artifact_registry_custom_endpoint": "artifactRegistryCustomEndpoint",
    "asset_names": "assetNames",
    "asset_types": "assetTypes",
    "attached_disks": "attachedDisks",
    "attachment_id": "attachmentId",
    "attempt_deadline": "attemptDeadline",
    "attestation_authority": "attestationAuthority",
    "attestation_authority_note": "attestationAuthorityNote",
    "audit_log_configs": "auditLogConfigs",
    "auth_domain": "authDomain",
    "authenticator_groups_config": "authenticatorGroupsConfig",
    "authorized_network": "authorizedNetwork",
    "authorized_networks": "authorizedNetworks",
    "auto_create_network": "autoCreateNetwork",
    "auto_create_subnetworks": "autoCreateSubnetworks",
    "auto_healing_policies": "autoHealingPolicies",
    "autogenerate_revision_name": "autogenerateRevisionName",
    "automatic_scaling": "automaticScaling",
    "autoscaling_policy": "autoscalingPolicy",
    "available_memory_mb": "availableMemoryMb",
    "avatar_uri": "avatarUri",
    "avatar_uri_backend": "avatarUriBackend",
    "backend_bucket": "backendBucket",
    "backend_service": "backendService",
    "backup_pool": "backupPool",
    "base_instance_name": "baseInstanceName",
    "basic_algorithm": "basicAlgorithm",
    "basic_scaling": "basicScaling",
    "basic_sli": "basicSli",
    "beta_settings": "betaSettings",
    "big_query_custom_endpoint": "bigQueryCustomEndpoint",
    "bigquery_connection_custom_endpoint": "bigqueryConnectionCustomEndpoint",
    "bigquery_data_transfer_custom_endpoint": "bigqueryDataTransferCustomEndpoint",
    "bigquery_date_sharded_spec": "bigqueryDateShardedSpec",
    "bigquery_options": "bigqueryOptions",
    "bigquery_reservation_custom_endpoint": "bigqueryReservationCustomEndpoint",
    "bigquery_table_spec": "bigqueryTableSpec",
    "bigtable_custom_endpoint": "bigtableCustomEndpoint",
    "billing_account": "billingAccount",
    "billing_account_id": "billingAccountId",
    "billing_custom_endpoint": "billingCustomEndpoint",
    "billing_project": "billingProject",
    "binary_authorization_custom_endpoint": "binaryAuthorizationCustomEndpoint",
    "blacklist_patterns": "blacklistPatterns",
    "boolean_policy": "booleanPolicy",
    "boot_disk": "bootDisk",
    "boot_disk_size_gb": "bootDiskSizeGb",
    "boot_disk_type": "bootDiskType",
    "bucket_id": "bucketId",
    "bucket_name": "bucketName",
    "bucket_options": "bucketOptions",
    "bucket_policy_only": "bucketPolicyOnly",
    "bucket_self_link": "bucketSelfLink",
    "budget_filter": "budgetFilter",
    "cache_control": "cacheControl",
    "calendar_period": "calendarPeriod",
    "can_ip_forward": "canIpForward",
    "candidate_subnets": "candidateSubnets",
    "cdn_policy": "cdnPolicy",
    "cert_serial_number": "certSerialNumber",
    "certificate_id": "certificateId",
    "check_interval_sec": "checkIntervalSec",
    "cidr_block": "cidrBlock",
    "circuit_breakers": "circuitBreakers",
    "classification_threshold": "classificationThreshold",
    "client_id": "clientId",
    "client_secret": "clientSecret",
    "cloud_asset_custom_endpoint": "cloudAssetCustomEndpoint",
    "cloud_billing_custom_endpoint": "cloudBillingCustomEndpoint",
    "cloud_build_custom_endpoint": "cloudBuildCustomEndpoint",
    "cloud_function": "cloudFunction",
    "cloud_functions_custom_endpoint": "cloudFunctionsCustomEndpoint",
    "cloud_identity_custom_endpoint": "cloudIdentityCustomEndpoint",
    "cloud_iot_custom_endpoint": "cloudIotCustomEndpoint",
    "cloud_router_ip_address": "cloudRouterIpAddress",
    "cloud_run": "cloudRun",
    "cloud_run_custom_endpoint": "cloudRunCustomEndpoint",
    "cloud_scheduler_custom_endpoint": "cloudSchedulerCustomEndpoint",
    "cloud_sql": "cloudSql",
    "cloud_tasks_custom_endpoint": "cloudTasksCustomEndpoint",
    "cluster_admission_rules": "clusterAdmissionRules",
    "cluster_autoscaling": "clusterAutoscaling",
    "cluster_config": "clusterConfig",
    "cluster_id": "clusterId",
    "cluster_ipv4_cidr": "clusterIpv4Cidr",
    "cluster_telemetry": "clusterTelemetry",
    "code_bucket": "codeBucket",
    "collector_ilb": "collectorIlb",
    "column_families": "columnFamilies",
    "column_family": "columnFamily",
    "common_name": "commonName",
    "composer_custom_endpoint": "composerCustomEndpoint",
    "compute_beta_custom_endpoint": "computeBetaCustomEndpoint",
    "compute_custom_endpoint": "computeCustomEndpoint",
    "confidential_instance_config": "confidentialInstanceConfig",
    "config_id": "configId",
    "connect_mode": "connectMode",
    "connection_draining_timeout_sec": "connectionDrainingTimeoutSec",
    "connection_id": "connectionId",
    "connection_info": "connectionInfo",
    "connection_name": "connectionName",
    "consistent_hash": "consistentHash",
    "container_analysis_custom_endpoint": "containerAnalysisCustomEndpoint",
    "container_beta_custom_endpoint": "containerBetaCustomEndpoint",
    "container_custom_endpoint": "containerCustomEndpoint",
    "container_image": "containerImage",
    "container_spec_gcs_path": "containerSpecGcsPath",
    "content_disposition": "contentDisposition",
    "content_encoding": "contentEncoding",
    "content_language": "contentLanguage",
    "content_matchers": "contentMatchers",
    "content_type": "contentType",
    "cpu_overcommit_type": "cpuOvercommitType",
    "cpu_platform": "cpuPlatform",
    "create_policy": "createPolicy",
    "create_time": "createTime",
    "creation_record": "creationRecord",
    "creation_time": "creationTime",
    "creation_timestamp": "creationTimestamp",
    "crypto_key": "cryptoKey",
    "crypto_key_id": "cryptoKeyId",
    "current_location_id": "currentLocationId",
    "current_status": "currentStatus",
    "custom_attributes": "customAttributes",
    "custom_features": "customFeatures",
    "custom_gpu_driver_path": "customGpuDriverPath",
    "custom_request_headers": "customRequestHeaders",
    "customer_router_ip_address": "customerRouterIpAddress",
    "dashboard_json": "dashboardJson",
    "data_catalog_custom_endpoint": "dataCatalogCustomEndpoint",
    "data_disk_size_gb": "dataDiskSizeGb",
    "data_disk_type": "dataDiskType",
    "data_fusion_custom_endpoint": "dataFusionCustomEndpoint",
    "data_refresh_window_days": "dataRefreshWindowDays",
    "data_source_id": "dataSourceId",
    "database_encryption": "databaseEncryption",
    "database_type": "databaseType",
    "database_version": "databaseVersion",
    "dataflow_custom_endpoint": "dataflowCustomEndpoint",
    "dataproc_beta_custom_endpoint": "dataprocBetaCustomEndpoint",
    "dataproc_custom_endpoint": "dataprocCustomEndpoint",
    "dataset_id": "datasetId",
    "datastore_custom_endpoint": "datastoreCustomEndpoint",
    "dead_letter_policy": "deadLetterPolicy",
    "default_acl": "defaultAcl",
    "default_admission_rule": "defaultAdmissionRule",
    "default_bucket": "defaultBucket",
    "default_encryption_configuration": "defaultEncryptionConfiguration",
    "default_event_based_hold": "defaultEventBasedHold",
    "default_expiration": "defaultExpiration",
    "default_game_server_config": "defaultGameServerConfig",
    "default_hostname": "defaultHostname",
    "default_language_code": "defaultLanguageCode",
    "default_max_pods_per_node": "defaultMaxPodsPerNode",
    "default_partition_expiration_ms": "defaultPartitionExpirationMs",
    "default_port": "defaultPort",
    "default_response_platforms": "defaultResponsePlatforms",
    "default_route_action": "defaultRouteAction",
    "default_service": "defaultService",
    "default_snat_status": "defaultSnatStatus",
    "default_table_expiration_ms": "defaultTableExpirationMs",
    "default_url_redirect": "defaultUrlRedirect",
    "default_version": "defaultVersion",
    "delete_contents_on_destroy": "deleteContentsOnDestroy",
    "delete_default_routes_on_create": "deleteDefaultRoutesOnCreate",
    "delete_policy": "deletePolicy",
    "delete_service_on_destroy": "deleteServiceOnDestroy",
    "deletion_protection": "deletionProtection",
    "deletion_time": "deletionTime",
    "deployment_id": "deploymentId",
    "deployment_manager_custom_endpoint": "deploymentManagerCustomEndpoint",
    "desired_status": "desiredStatus",
    "dest_range": "destRange",
    "destination_dataset_id": "destinationDatasetId",
    "destination_ranges": "destinationRanges",
    "destroy_time": "destroyTime",
    "detailed_status": "detailedStatus",
    "detect_md5hash": "detectMd5hash",
    "device_name": "deviceName",
    "dialogflow_custom_endpoint": "dialogflowCustomEndpoint",
    "dicom_store_id": "dicomStoreId",
    "disable_auth": "disableAuth",
    "disable_dependent_services": "disableDependentServices",
    "disable_on_destroy": "disableOnDestroy",
    "disable_referential_integrity": "disableReferentialIntegrity",
    "disable_resource_versioning": "disableResourceVersioning",
    "disk_encryption": "diskEncryption",
    "disk_encryption_key": "diskEncryptionKey",
    "disk_size_gb": "diskSizeGb",
    "dispatch_rules": "dispatchRules",
    "display_name": "displayName",
    "distribution_policy_zones": "distributionPolicyZones",
    "dns_address": "dnsAddress",
    "dns_beta_custom_endpoint": "dnsBetaCustomEndpoint",
    "dns_custom_endpoint": "dnsCustomEndpoint",
    "dns_name": "dnsName",
    "dnssec_config": "dnssecConfig",
    "domain_name": "domainName",
    "drain_nat_ips": "drainNatIps",
    "driver_controls_files_uri": "driverControlsFilesUri",
    "driver_output_resource_uri": "driverOutputResourceUri",
    "edge_availability_domain": "edgeAvailabilityDomain",
    "enable_batching": "enableBatching",
    "enable_binary_authorization": "enableBinaryAuthorization",
    "enable_cdn": "enableCdn",
    "enable_display": "enableDisplay",
    "enable_email_link_signin": "enableEmailLinkSignin",
    "enable_fuzzy_extraction": "enableFuzzyExtraction",
    "enable_history_import": "enableHistoryImport",
    "enable_inbound_forwarding": "enableInboundForwarding",
    "enable_intranode_visibility": "enableIntranodeVisibility",
    "enable_kubernetes_alpha": "enableKubernetesAlpha",
    "enable_legacy_abac": "enableLegacyAbac",
    "enable_logging": "enableLogging",
    "enable_shielded_nodes": "enableShieldedNodes",
    "enable_stackdriver_logging": "enableStackdriverLogging",
    "enable_stackdriver_monitoring": "enableStackdriverMonitoring",
    "enable_tpu": "enableTpu",
    "enable_update_create": "enableUpdateCreate",
    "enabled_features": "enabledFeatures",
    "encryption_configuration": "encryptionConfiguration",
    "encryption_key_name": "encryptionKeyName",
    "endpoint_id": "endpointId",
    "endpoints_api_service": "endpointsApiService",
    "entity_id": "entityId",
    "entry_group": "entryGroup",
    "entry_group_id": "entryGroupId",
    "entry_id": "entryId",
    "entry_point": "entryPoint",
    "env_variables": "envVariables",
    "environment_variables": "environmentVariables",
    "event_notification_configs": "eventNotificationConfigs",
    "event_trigger": "eventTrigger",
    "event_types": "eventTypes",
    "expiration_policy": "expirationPolicy",
    "expiration_time": "expirationTime",
    "expiration_time_usec": "expirationTimeUsec",
    "expire_time": "expireTime",
    "export_custom_routes": "exportCustomRoutes",
    "export_subnet_routes_with_public_ip": "exportSubnetRoutesWithPublicIp",
    "export_to_security_command_center": "exportToSecurityCommandCenter",
    "external_data_configuration": "externalDataConfiguration",
    "failover_policy": "failoverPolicy",
    "failover_ratio": "failoverRatio",
    "feature_settings": "featureSettings",
    "feed_id": "feedId",
    "feed_output_config": "feedOutputConfig",
    "fhir_store_id": "fhirStoreId",
    "file_shares": "fileShares",
    "filestore_custom_endpoint": "filestoreCustomEndpoint",
    "firebase_custom_endpoint": "firebaseCustomEndpoint",
    "firestore_custom_endpoint": "firestoreCustomEndpoint",
    "first_ip_address": "firstIpAddress",
    "fleet_configs": "fleetConfigs",
    "folder_id": "folderId",
    "followup_intent_infos": "followupIntentInfos",
    "force_delete": "forceDelete",
    "force_destroy": "forceDestroy",
    "forwarding_config": "forwardingConfig",
    "friendly_name": "friendlyName",
    "game_server_config_overrides": "gameServerConfigOverrides",
    "game_services_custom_endpoint": "gameServicesCustomEndpoint",
    "gateway_address": "gatewayAddress",
    "gateway_config": "gatewayConfig",
    "gateway_id": "gatewayId",
    "gateway_ipv4": "gatewayIpv4",
    "gcr_domain": "gcrDomain",
    "gcs_fileset_spec": "gcsFilesetSpec",
    "global_network_endpoint_group": "globalNetworkEndpointGroup",
    "global_policy_evaluation_mode": "globalPolicyEvaluationMode",
    "google_reference_id": "googleReferenceId",
    "group_by_email": "groupByEmail",
    "group_key": "groupKey",
    "group_placement_policy": "groupPlacementPolicy",
    "grpc_config": "grpcConfig",
    "guest_accelerators": "guestAccelerators",
    "guest_os_features": "guestOsFeatures",
    "guest_policy_id": "guestPolicyId",
    "hadoop_config": "hadoopConfig",
    "has_credential": "hasCredential",
    "header_action": "headerAction",
    "health_checks": "healthChecks",
    "healthcare_custom_endpoint": "healthcareCustomEndpoint",
    "healthy_threshold": "healthyThreshold",
    "hive_config": "hiveConfig",
    "hl7_v2_store_id": "hl7V2StoreId",
    "host_project": "hostProject",
    "host_rules": "hostRules",
    "http2_health_check": "http2HealthCheck",
    "http_check": "httpCheck",
    "http_config": "httpConfig",
    "http_enabled_state": "httpEnabledState",
    "http_health_check": "httpHealthCheck",
    "http_target": "httpTarget",
    "https_health_check": "httpsHealthCheck",
    "https_trigger_url": "httpsTriggerUrl",
    "iam_credentials_custom_endpoint": "iamCredentialsCustomEndpoint",
    "iam_custom_endpoint": "iamCustomEndpoint",
    "iam_member": "iamMember",
    "iap_custom_endpoint": "iapCustomEndpoint",
    "icmp_idle_timeout_sec": "icmpIdleTimeoutSec",
    "identity_platform_custom_endpoint": "identityPlatformCustomEndpoint",
    "idp_config": "idpConfig",
    "idp_id": "idpId",
    "ignore_idle_slots": "ignoreIdleSlots",
    "ignore_warnings": "ignoreWarnings",
    "ignored_files": "ignoredFiles",
    "ike_version": "ikeVersion",
    "import_custom_routes": "importCustomRoutes",
    "import_job_id": "importJobId",
    "import_method": "importMethod",
    "import_subnet_routes_with_public_ip": "importSubnetRoutesWithPublicIp",
    "inbound_services": "inboundServices",
    "include_children": "includeChildren",
    "included_files": "includedFiles",
    "index_id": "indexId",
    "ingress_settings": "ingressSettings",
    "initial_node_count": "initialNodeCount",
    "input_context_names": "inputContextNames",
    "install_gpu_driver": "installGpuDriver",
    "instance_class": "instanceClass",
    "instance_description": "instanceDescription",
    "instance_filter": "instanceFilter",
    "instance_group": "instanceGroup",
    "instance_group_manager": "instanceGroupManager",
    "instance_group_urls": "instanceGroupUrls",
    "instance_id": "instanceId",
    "instance_name": "instanceName",
    "instance_owners": "instanceOwners",
    "instance_type": "instanceType",
    "integrated_system": "integratedSystem",
    "interconnect_attachment": "interconnectAttachment",
    "ip_address": "ipAddress",
    "ip_addresses": "ipAddresses",
    "ip_allocation_policy": "ipAllocationPolicy",
    "ip_cidr_range": "ipCidrRange",
    "ip_configuration": "ipConfiguration",
    "ip_protocol": "ipProtocol",
    "ip_range": "ipRange",
    "ip_version": "ipVersion",
    "is_cluster": "isCluster",
    "is_fallback": "isFallback",
    "is_mirroring_collector": "isMirroringCollector",
    "job_id": "jobId",
    "job_timeout_ms": "jobTimeoutMs",
    "job_type": "jobType",
    "key_algorithm": "keyAlgorithm",
    "key_ring": "keyRing",
    "key_ring_id": "keyRingId",
    "key_value": "keyValue",
    "kms_custom_endpoint": "kmsCustomEndpoint",
    "kms_key": "kmsKey",
    "kms_key_name": "kmsKeyName",
    "label_extractors": "labelExtractors",
    "label_fingerprint": "labelFingerprint",
    "last_attach_timestamp": "lastAttachTimestamp",
    "last_config_ack_time": "lastConfigAckTime",
    "last_config_send_time": "lastConfigSendTime",
    "last_detach_timestamp": "lastDetachTimestamp",
    "last_error_status": "lastErrorStatus",
    "last_error_time": "lastErrorTime",
    "last_event_time": "lastEventTime",
    "last_execute_time": "lastExecuteTime",
    "last_heartbeat_time": "lastHeartbeatTime",
    "last_modification_time": "lastModificationTime",
    "last_modified_time": "lastModifiedTime",
    "last_state_time": "lastStateTime",
    "launch_stage": "launchStage",
    "lifecycle_rules": "lifecycleRules",
    "lifecycle_state": "lifecycleState",
    "linked_resource": "linkedResource",
    "list_policy": "listPolicy",
    "liveness_check": "livenessCheck",
    "load_balancing_scheme": "loadBalancingScheme",
    "local_traffic_selectors": "localTrafficSelectors",
    "locality_lb_policy": "localityLbPolicy",
    "location_id": "locationId",
    "log_config": "logConfig",
    "log_level": "logLevel",
    "logging_custom_endpoint": "loggingCustomEndpoint",
    "logging_service": "loggingService",
    "long_description": "longDescription",
    "machine_type": "machineType",
    "maintenance_policy": "maintenancePolicy",
    "managed_zone": "managedZone",
    "management_type": "managementType",
    "manual_scaling": "manualScaling",
    "map_id": "mapId",
    "master_auth": "masterAuth",
    "master_authorized_networks_config": "masterAuthorizedNetworksConfig",
    "master_instance_name": "masterInstanceName",
    "master_version": "masterVersion",
    "match_mode": "matchMode",
    "max_ages": "maxAges",
    "max_instances": "maxInstances",
    "max_pods_per_node": "maxPodsPerNode",
    "max_qps": "maxQps",
    "max_throughput": "maxThroughput",
    "max_versions": "maxVersions",
    "max_workers": "maxWorkers",
    "media_link": "mediaLink",
    "member_key": "memberKey",
    "memcache_custom_endpoint": "memcacheCustomEndpoint",
    "memcache_full_version": "memcacheFullVersion",
    "memcache_nodes": "memcacheNodes",
    "memcache_parameters": "memcacheParameters",
    "memcache_version": "memcacheVersion",
    "memory_size_gb": "memorySizeGb",
    "message_retention_duration": "messageRetentionDuration",
    "message_storage_policy": "messageStoragePolicy",
    "metadata_filters": "metadataFilters",
    "metadata_fingerprint": "metadataFingerprint",
    "metadata_startup_script": "metadataStartupScript",
    "metric_descriptor": "metricDescriptor",
    "metric_kind": "metricKind",
    "migrate_traffic": "migrateTraffic",
    "min_cpu_platform": "minCpuPlatform",
    "min_master_version": "minMasterVersion",
    "min_ports_per_vm": "minPortsPerVm",
    "min_throughput": "minThroughput",
    "min_tls_version": "minTlsVersion",
    "minimal_action": "minimalAction",
    "mirrored_resources": "mirroredResources",
    "ml_disabled": "mlDisabled",
    "ml_engine_custom_endpoint": "mlEngineCustomEndpoint",
    "monitored_resource": "monitoredResource",
    "monitored_resource_types": "monitoredResourceTypes",
    "monitoring_custom_endpoint": "monitoringCustomEndpoint",
    "monitoring_service": "monitoringService",
    "most_disruptive_allowed_action": "mostDisruptiveAllowedAction",
    "mqtt_config": "mqttConfig",
    "mqtt_enabled_state": "mqttEnabledState",
    "multi_cluster_routing_use_any": "multiClusterRoutingUseAny",
    "name_prefix": "namePrefix",
    "name_servers": "nameServers",
    "named_ports": "namedPorts",
    "namespace_id": "namespaceId",
    "nat_ip_allocate_option": "natIpAllocateOption",
    "nat_ips": "natIps",
    "nat_policy": "natPolicy",
    "network_config": "networkConfig",
    "network_endpoint_group": "networkEndpointGroup",
    "network_endpoint_type": "networkEndpointType",
    "network_endpoints": "networkEndpoints",
    "network_interfaces": "networkInterfaces",
    "network_management_custom_endpoint": "networkManagementCustomEndpoint",
    "network_policy": "networkPolicy",
    "network_tier": "networkTier",
    "networking_mode": "networkingMode",
    "next_hop_gateway": "nextHopGateway",
    "next_hop_ilb": "nextHopIlb",
    "next_hop_instance": "nextHopInstance",
    "next_hop_instance_zone": "nextHopInstanceZone",
    "next_hop_ip": "nextHopIp",
    "next_hop_network": "nextHopNetwork",
    "next_hop_vpn_tunnel": "nextHopVpnTunnel",
    "no_proxy_access": "noProxyAccess",
    "no_public_ip": "noPublicIp",
    "no_remove_data_disk": "noRemoveDataDisk",
    "nobuild_files_regex": "nobuildFilesRegex",
    "node_affinity_labels": "nodeAffinityLabels",
    "node_config": "nodeConfig",
    "node_count": "nodeCount",
    "node_locations": "nodeLocations",
    "node_pools": "nodePools",
    "node_template": "nodeTemplate",
    "node_type": "nodeType",
    "node_type_flexibility": "nodeTypeFlexibility",
    "node_version": "nodeVersion",
    "noop_on_destroy": "noopOnDestroy",
    "note_name": "noteName",
    "notebooks_custom_endpoint": "notebooksCustomEndpoint",
    "notification_channels": "notificationChannels",
    "notification_config": "notificationConfig",
    "notification_configs": "notificationConfigs",
    "notification_id": "notificationId",
    "num_bytes": "numBytes",
    "num_id": "numId",
    "num_long_term_bytes": "numLongTermBytes",
    "num_nodes": "numNodes",
    "num_rows": "numRows",
    "object_name_prefix": "objectNamePrefix",
    "on_delete": "onDelete",
    "one_time_schedule": "oneTimeSchedule",
    "online_prediction_console_logging": "onlinePredictionConsoleLogging",
    "online_prediction_logging": "onlinePredictionLogging",
    "openapi_config": "openapiConfig",
    "org_id": "orgId",
    "org_internal_only": "orgInternalOnly",
    "os_config_custom_endpoint": "osConfigCustomEndpoint",
    "os_login_custom_endpoint": "osLoginCustomEndpoint",
    "outlier_detection": "outlierDetection",
    "output_name": "outputName",
    "override_strategy": "overrideStrategy",
    "override_value": "overrideValue",
    "package_repositories": "packageRepositories",
    "pairing_key": "pairingKey",
    "parent_followup_intent_name": "parentFollowupIntentName",
    "parent_name": "parentName",
    "parser_config": "parserConfig",
    "partner_asn": "partnerAsn",
    "patch_config": "patchConfig",
    "patch_deployment_id": "patchDeploymentId",
    "path_matchers": "pathMatchers",
    "payload_format": "payloadFormat",
    "peer_asn": "peerAsn",
    "peer_external_gateway": "peerExternalGateway",
    "peer_external_gateway_interface": "peerExternalGatewayInterface",
    "peer_gcp_gateway": "peerGcpGateway",
    "peer_ip": "peerIp",
    "peer_ip_address": "peerIpAddress",
    "peer_network": "peerNetwork",
    "peering_config": "peeringConfig",
    "perimeter_name": "perimeterName",
    "perimeter_type": "perimeterType",
    "persistence_iam_identity": "persistenceIamIdentity",
    "physical_block_size_bytes": "physicalBlockSizeBytes",
    "pig_config": "pigConfig",
    "pod_security_policy_config": "podSecurityPolicyConfig",
    "policy_data": "policyData",
    "policy_id": "policyId",
    "port_name": "portName",
    "port_range": "portRange",
    "post_startup_script": "postStartupScript",
    "predefined_acl": "predefinedAcl",
    "preferred_member_key": "preferredMemberKey",
    "prefix_length": "prefixLength",
    "preserved_state": "preservedState",
    "private_cluster_config": "privateClusterConfig",
    "private_instance": "privateInstance",
    "private_interconnect_info": "privateInterconnectInfo",
    "private_ip_address": "privateIpAddress",
    "private_ip_google_access": "privateIpGoogleAccess",
    "private_key": "privateKey",
    "private_key_type": "privateKeyType",
    "private_visibility_config": "privateVisibilityConfig",
    "project_id": "projectId",
    "project_number": "projectNumber",
    "project_team": "projectTeam",
    "protection_level": "protectionLevel",
    "protoc_output_base64": "protocOutputBase64",
    "proxy_header": "proxyHeader",
    "proxy_id": "proxyId",
    "proxy_uri": "proxyUri",
    "public_ip_address": "publicIpAddress",
    "public_key": "publicKey",
    "public_key_data": "publicKeyData",
    "public_key_type": "publicKeyType",
    "pubsub_configs": "pubsubConfigs",
    "pubsub_custom_endpoint": "pubsubCustomEndpoint",
    "pubsub_target": "pubsubTarget",
    "pubsub_topic_name": "pubsubTopicName",
    "push_config": "pushConfig",
    "pyspark_config": "pysparkConfig",
    "query_scope": "queryScope",
    "quic_override": "quicOverride",
    "range_partitioning": "rangePartitioning",
    "rate_limits": "rateLimits",
    "raw_disk": "rawDisk",
    "readiness_check": "readinessCheck",
    "realm_id": "realmId",
    "recurring_schedule": "recurringSchedule",
    "redis_configs": "redisConfigs",
    "redis_custom_endpoint": "redisCustomEndpoint",
    "redis_version": "redisVersion",
    "redundancy_type": "redundancyType",
    "region_instance_group_manager": "regionInstanceGroupManager",
    "related_note_names": "relatedNoteNames",
    "related_projects": "relatedProjects",
    "related_urls": "relatedUrls",
    "release_channel": "releaseChannel",
    "remote_traffic_selectors": "remoteTrafficSelectors",
    "remove_default_node_pool": "removeDefaultNodePool",
    "remove_instance_state_on_destroy": "removeInstanceStateOnDestroy",
    "replica_configuration": "replicaConfiguration",
    "replica_zones": "replicaZones",
    "repository_id": "repositoryId",
    "request_based_sli": "requestBasedSli",
    "request_path": "requestPath",
    "request_timeout": "requestTimeout",
    "requester_pays": "requesterPays",
    "reserved_ip_range": "reservedIpRange",
    "reserved_peering_ranges": "reservedPeeringRanges",
    "reset_contexts": "resetContexts",
    "resource_group": "resourceGroup",
    "resource_labels": "resourceLabels",
    "resource_manager_custom_endpoint": "resourceManagerCustomEndpoint",
    "resource_manager_v2beta1_custom_endpoint": "resourceManagerV2beta1CustomEndpoint",
    "resource_policies": "resourcePolicies",
    "resource_records": "resourceRecords",
    "resource_uri": "resourceUri",
    "resource_usage_export_config": "resourceUsageExportConfig",
    "restore_policy": "restorePolicy",
    "retain_acked_messages": "retainAckedMessages",
    "retention_days": "retentionDays",
    "retention_policy": "retentionPolicy",
    "retry_config": "retryConfig",
    "reverse_lookup": "reverseLookup",
    "role_entities": "roleEntities",
    "role_id": "roleId",
    "rolling_period_days": "rollingPeriodDays",
    "root_followup_intent_name": "rootFollowupIntentName",
    "root_password": "rootPassword",
    "rotation_period": "rotationPeriod",
    "routing_mode": "routingMode",
    "runtime_api_version": "runtimeApiVersion",
    "runtime_channel": "runtimeChannel",
    "runtime_config_custom_endpoint": "runtimeConfigCustomEndpoint",
    "runtime_main_executable_path": "runtimeMainExecutablePath",
    "runtimeconfig_custom_endpoint": "runtimeconfigCustomEndpoint",
    "scaling_configs": "scalingConfigs",
    "scheduling_config": "schedulingConfig",
    "scratch_disks": "scratchDisks",
    "secondary_ip_ranges": "secondaryIpRanges",
    "secondary_worker_config": "secondaryWorkerConfig",
    "secret_data": "secretData",
    "secret_id": "secretId",
    "secret_manager_custom_endpoint": "secretManagerCustomEndpoint",
    "security_center_custom_endpoint": "securityCenterCustomEndpoint",
    "security_policy": "securityPolicy",
    "security_scanner_custom_endpoint": "securityScannerCustomEndpoint",
    "selected_regions": "selectedRegions",
    "self_link": "selfLink",
    "send_after": "sendAfter",
    "sensitive_labels": "sensitiveLabels",
    "server_binding": "serverBinding",
    "server_ca_cert": "serverCaCert",
    "service_account": "serviceAccount",
    "service_account_email": "serviceAccountEmail",
    "service_account_email_address": "serviceAccountEmailAddress",
    "service_account_id": "serviceAccountId",
    "service_account_name": "serviceAccountName",
    "service_directory_config": "serviceDirectoryConfig",
    "service_directory_custom_endpoint": "serviceDirectoryCustomEndpoint",
    "service_endpoint": "serviceEndpoint",
    "service_id": "serviceId",
    "service_label": "serviceLabel",
    "service_management_custom_endpoint": "serviceManagementCustomEndpoint",
    "service_name": "serviceName",
    "service_networking_custom_endpoint": "serviceNetworkingCustomEndpoint",
    "service_project": "serviceProject",
    "service_usage_custom_endpoint": "serviceUsageCustomEndpoint",
    "services_ipv4_cidr": "servicesIpv4Cidr",
    "serving_status": "servingStatus",
    "session_affinity": "sessionAffinity",
    "sha1_fingerprint": "sha1Fingerprint",
    "shared_secret": "sharedSecret",
    "shared_secret_hash": "sharedSecretHash",
    "shielded_instance_config": "shieldedInstanceConfig",
    "short_description": "shortDescription",
    "single_cluster_routing": "singleClusterRouting",
    "skip_delete": "skipDelete",
    "slo_id": "sloId",
    "slot_capacity": "slotCapacity",
    "snapshot_encryption_key": "snapshotEncryptionKey",
    "snapshot_id": "snapshotId",
    "snapshot_schedule_policy": "snapshotSchedulePolicy",
    "source_archive_bucket": "sourceArchiveBucket",
    "source_archive_object": "sourceArchiveObject",
    "source_disk": "sourceDisk",
    "source_disk_encryption_key": "sourceDiskEncryptionKey",
    "source_disk_link": "sourceDiskLink",
    "source_image": "sourceImage",
    "source_image_encryption_key": "sourceImageEncryptionKey",
    "source_image_id": "sourceImageId",
    "source_instance": "sourceInstance",
    "source_instance_template": "sourceInstanceTemplate",
    "source_range": "sourceRange",
    "source_ranges": "sourceRanges",
    "source_repo_custom_endpoint": "sourceRepoCustomEndpoint",
    "source_repository": "sourceRepository",
    "source_service_accounts": "sourceServiceAccounts",
    "source_snapshot": "sourceSnapshot",
    "source_snapshot_encryption_key": "sourceSnapshotEncryptionKey",
    "source_snapshot_id": "sourceSnapshotId",
    "source_subnetwork_ip_ranges_to_nat": "sourceSubnetworkIpRangesToNat",
    "source_tags": "sourceTags",
    "sp_config": "spConfig",
    "spanner_custom_endpoint": "spannerCustomEndpoint",
    "spark_config": "sparkConfig",
    "sparksql_config": "sparksqlConfig",
    "special_group": "specialGroup",
    "specific_reservation": "specificReservation",
    "specific_reservation_required": "specificReservationRequired",
    "split_keys": "splitKeys",
    "sql_custom_endpoint": "sqlCustomEndpoint",
    "ssl_certificates": "sslCertificates",
    "ssl_health_check": "sslHealthCheck",
    "ssl_policy": "sslPolicy",
    "ssl_settings": "sslSettings",
    "starting_urls": "startingUrls",
    "state_details": "stateDetails",
    "state_message": "stateMessage",
    "state_notification_config": "stateNotificationConfig",
    "stateful_disks": "statefulDisks",
    "storage_bytes": "storageBytes",
    "storage_class": "storageClass",
    "storage_custom_endpoint": "storageCustomEndpoint",
    "storage_transfer_custom_endpoint": "storageTransferCustomEndpoint",
    "stream_configs": "streamConfigs",
    "subject_alternative_names": "subjectAlternativeNames",
    "support_email": "supportEmail",
    "supported_language_codes": "supportedLanguageCodes",
    "table_id": "tableId",
    "tag_template_id": "tagTemplateId",
    "tags_fingerprint": "tagsFingerprint",
    "target_platforms": "targetPlatforms",
    "target_pools": "targetPools",
    "target_resources": "targetResources",
    "target_service_accounts": "targetServiceAccounts",
    "target_size": "targetSize",
    "target_tags": "targetTags",
    "target_vpn_gateway": "targetVpnGateway",
    "tcp_check": "tcpCheck",
    "tcp_established_idle_timeout_sec": "tcpEstablishedIdleTimeoutSec",
    "tcp_health_check": "tcpHealthCheck",
    "tcp_transitory_idle_timeout_sec": "tcpTransitoryIdleTimeoutSec",
    "temp_gcs_location": "tempGcsLocation",
    "template_displayname": "templateDisplayname",
    "template_gcs_path": "templateGcsPath",
    "tensorflow_version": "tensorflowVersion",
    "threshold_rules": "thresholdRules",
    "time_created": "timeCreated",
    "time_partitioning": "timePartitioning",
    "time_zone": "timeZone",
    "timeout_sec": "timeoutSec",
    "tpu_custom_endpoint": "tpuCustomEndpoint",
    "tpu_ipv4_cidr_block": "tpuIpv4CidrBlock",
    "transfer_spec": "transferSpec",
    "trigger_http": "triggerHttp",
    "trigger_id": "triggerId",
    "trigger_template": "triggerTemplate",
    "tunnel_id": "tunnelId",
    "udp_idle_timeout_sec": "udpIdleTimeoutSec",
    "unhealthy_threshold": "unhealthyThreshold",
    "unique_id": "uniqueId",
    "unique_writer_identity": "uniqueWriterIdentity",
    "update_policy": "updatePolicy",
    "update_time": "updateTime",
    "upgrade_settings": "upgradeSettings",
    "uptime_check_id": "uptimeCheckId",
    "url_dispatch_rules": "urlDispatchRules",
    "url_map": "urlMap",
    "use_explicit_dry_run_spec": "useExplicitDryRunSpec",
    "user_agent": "userAgent",
    "user_by_email": "userByEmail",
    "user_email": "userEmail",
    "user_labels": "userLabels",
    "user_project_override": "userProjectOverride",
    "user_specified_system": "userSpecifiedSystem",
    "user_specified_type": "userSpecifiedType",
    "valid_after": "validAfter",
    "valid_before": "validBefore",
    "value_extractor": "valueExtractor",
    "value_type": "valueType",
    "verification_status": "verificationStatus",
    "version_id": "versionId",
    "version_template": "versionTemplate",
    "vertical_pod_autoscaling": "verticalPodAutoscaling",
    "vlan_tag8021q": "vlanTag8021q",
    "vm_image": "vmImage",
    "vpc_access_connector": "vpcAccessConnector",
    "vpc_access_custom_endpoint": "vpcAccessCustomEndpoint",
    "vpc_connector": "vpcConnector",
    "vpc_connector_egress_settings": "vpcConnectorEgressSettings",
    "vpn_gateway": "vpnGateway",
    "vpn_gateway_interface": "vpnGatewayInterface",
    "vpn_interfaces": "vpnInterfaces",
    "vpn_tunnel": "vpnTunnel",
    "wait_for_instances": "waitForInstances",
    "web_backend_service": "webBackendService",
    "webhook_state": "webhookState",
    "windows_based_sli": "windowsBasedSli",
    "worker_config": "workerConfig",
    "workload_identity_config": "workloadIdentityConfig",
    "writer_identity": "writerIdentity",
}

CAMEL_TO_SNAKE_CASE_TABLE = {
    "acceleratorConfig": "accelerator_config",
    "acceleratorType": "accelerator_type",
    "accessContextManagerCustomEndpoint": "access_context_manager_custom_endpoint",
    "accessId": "access_id",
    "accessToken": "access_token",
    "accountId": "account_id",
    "ackDeadlineSeconds": "ack_deadline_seconds",
    "activeDirectoryCustomEndpoint": "active_directory_custom_endpoint",
    "additionalAuthenticatedData": "additional_authenticated_data",
    "additionalExperiments": "additional_experiments",
    "addonsConfig": "addons_config",
    "addressType": "address_type",
    "adminEnabled": "admin_enabled",
    "admissionWhitelistPatterns": "admission_whitelist_patterns",
    "advertiseMode": "advertise_mode",
    "advertisedGroups": "advertised_groups",
    "advertisedIpRanges": "advertised_ip_ranges",
    "advertisedRoutePriority": "advertised_route_priority",
    "affinityCookieTtlSec": "affinity_cookie_ttl_sec",
    "allPorts": "all_ports",
    "allUpdatesRule": "all_updates_rule",
    "allowGlobalAccess": "allow_global_access",
    "allowPasswordSignup": "allow_password_signup",
    "allowStoppingForUpdate": "allow_stopping_for_update",
    "alternativeLocationId": "alternative_location_id",
    "alternativeNameServerConfig": "alternative_name_server_config",
    "apiConfig": "api_config",
    "apiVersion": "api_version",
    "appEngine": "app_engine",
    "appEngineCustomEndpoint": "app_engine_custom_endpoint",
    "appEngineHttpTarget": "app_engine_http_target",
    "appEngineRoutingOverride": "app_engine_routing_override",
    "appId": "app_id",
    "appProfileId": "app_profile_id",
    "applicationTitle": "application_title",
    "archiveSizeBytes": "archive_size_bytes",
    "artifactRegistryCustomEndpoint": "artifact_registry_custom_endpoint",
    "assetNames": "asset_names",
    "assetTypes": "asset_types",
    "attachedDisks": "attached_disks",
    "attachmentId": "attachment_id",
    "attemptDeadline": "attempt_deadline",
    "attestationAuthority": "attestation_authority",
    "attestationAuthorityNote": "attestation_authority_note",
    "auditLogConfigs": "audit_log_configs",
    "authDomain": "auth_domain",
    "authenticatorGroupsConfig": "authenticator_groups_config",
    "authorizedNetwork": "authorized_network",
    "authorizedNetworks": "authorized_networks",
    "autoCreateNetwork": "auto_create_network",
    "autoCreateSubnetworks": "auto_create_subnetworks",
    "autoHealingPolicies": "auto_healing_policies",
    "autogenerateRevisionName": "autogenerate_revision_name",
    "automaticScaling": "automatic_scaling",
    "autoscalingPolicy": "autoscaling_policy",
    "availableMemoryMb": "available_memory_mb",
    "avatarUri": "avatar_uri",
    "avatarUriBackend": "avatar_uri_backend",
    "backendBucket": "backend_bucket",
    "backendService": "backend_service",
    "backupPool": "backup_pool",
    "baseInstanceName": "base_instance_name",
    "basicAlgorithm": "basic_algorithm",
    "basicScaling": "basic_scaling",
    "basicSli": "basic_sli",
    "betaSettings": "beta_settings",
    "bigQueryCustomEndpoint": "big_query_custom_endpoint",
    "bigqueryConnectionCustomEndpoint": "bigquery_connection_custom_endpoint",
    "bigqueryDataTransferCustomEndpoint": "bigquery_data_transfer_custom_endpoint",
    "bigqueryDateShardedSpec": "bigquery_date_sharded_spec",
    "bigqueryOptions": "bigquery_options",
    "bigqueryReservationCustomEndpoint": "bigquery_reservation_custom_endpoint",
    "bigqueryTableSpec": "bigquery_table_spec",
    "bigtableCustomEndpoint": "bigtable_custom_endpoint",
    "billingAccount": "billing_account",
    "billingAccountId": "billing_account_id",
    "billingCustomEndpoint": "billing_custom_endpoint",
    "billingProject": "billing_project",
    "binaryAuthorizationCustomEndpoint": "binary_authorization_custom_endpoint",
    "blacklistPatterns": "blacklist_patterns",
    "booleanPolicy": "boolean_policy",
    "bootDisk": "boot_disk",
    "bootDiskSizeGb": "boot_disk_size_gb",
    "bootDiskType": "boot_disk_type",
    "bucketId": "bucket_id",
    "bucketName": "bucket_name",
    "bucketOptions": "bucket_options",
    "bucketPolicyOnly": "bucket_policy_only",
    "bucketSelfLink": "bucket_self_link",
    "budgetFilter": "budget_filter",
    "cacheControl": "cache_control",
    "calendarPeriod": "calendar_period",
    "canIpForward": "can_ip_forward",
    "candidateSubnets": "candidate_subnets",
    "cdnPolicy": "cdn_policy",
    "certSerialNumber": "cert_serial_number",
    "certificateId": "certificate_id",
    "checkIntervalSec": "check_interval_sec",
    "cidrBlock": "cidr_block",
    "circuitBreakers": "circuit_breakers",
    "classificationThreshold": "classification_threshold",
    "clientId": "client_id",
    "clientSecret": "client_secret",
    "cloudAssetCustomEndpoint": "cloud_asset_custom_endpoint",
    "cloudBillingCustomEndpoint": "cloud_billing_custom_endpoint",
    "cloudBuildCustomEndpoint": "cloud_build_custom_endpoint",
    "cloudFunction": "cloud_function",
    "cloudFunctionsCustomEndpoint": "cloud_functions_custom_endpoint",
    "cloudIdentityCustomEndpoint": "cloud_identity_custom_endpoint",
    "cloudIotCustomEndpoint": "cloud_iot_custom_endpoint",
    "cloudRouterIpAddress": "cloud_router_ip_address",
    "cloudRun": "cloud_run",
    "cloudRunCustomEndpoint": "cloud_run_custom_endpoint",
    "cloudSchedulerCustomEndpoint": "cloud_scheduler_custom_endpoint",
    "cloudSql": "cloud_sql",
    "cloudTasksCustomEndpoint": "cloud_tasks_custom_endpoint",
    "clusterAdmissionRules": "cluster_admission_rules",
    "clusterAutoscaling": "cluster_autoscaling",
    "clusterConfig": "cluster_config",
    "clusterId": "cluster_id",
    "clusterIpv4Cidr": "cluster_ipv4_cidr",
    "clusterTelemetry": "cluster_telemetry",
    "codeBucket": "code_bucket",
    "collectorIlb": "collector_ilb",
    "columnFamilies": "column_families",
    "columnFamily": "column_family",
    "commonName": "common_name",
    "composerCustomEndpoint": "composer_custom_endpoint",
    "computeBetaCustomEndpoint": "compute_beta_custom_endpoint",
    "computeCustomEndpoint": "compute_custom_endpoint",
    "confidentialInstanceConfig": "confidential_instance_config",
    "configId": "config_id",
    "connectMode": "connect_mode",
    "connectionDrainingTimeoutSec": "connection_draining_timeout_sec",
    "connectionId": "connection_id",
    "connectionInfo": "connection_info",
    "connectionName": "connection_name",
    "consistentHash": "consistent_hash",
    "containerAnalysisCustomEndpoint": "container_analysis_custom_endpoint",
    "containerBetaCustomEndpoint": "container_beta_custom_endpoint",
    "containerCustomEndpoint": "container_custom_endpoint",
    "containerImage": "container_image",
    "containerSpecGcsPath": "container_spec_gcs_path",
    "contentDisposition": "content_disposition",
    "contentEncoding": "content_encoding",
    "contentLanguage": "content_language",
    "contentMatchers": "content_matchers",
    "contentType": "content_type",
    "cpuOvercommitType": "cpu_overcommit_type",
    "cpuPlatform": "cpu_platform",
    "createPolicy": "create_policy",
    "createTime": "create_time",
    "creationRecord": "creation_record",
    "creationTime": "creation_time",
    "creationTimestamp": "creation_timestamp",
    "cryptoKey": "crypto_key",
    "cryptoKeyId": "crypto_key_id",
    "currentLocationId": "current_location_id",
    "currentStatus": "current_status",
    "customAttributes": "custom_attributes",
    "customFeatures": "custom_features",
    "customGpuDriverPath": "custom_gpu_driver_path",
    "customRequestHeaders": "custom_request_headers",
    "customerRouterIpAddress": "customer_router_ip_address",
    "dashboardJson": "dashboard_json",
    "dataCatalogCustomEndpoint": "data_catalog_custom_endpoint",
    "dataDiskSizeGb": "data_disk_size_gb",
    "dataDiskType": "data_disk_type",
    "dataFusionCustomEndpoint": "data_fusion_custom_endpoint",
    "dataRefreshWindowDays": "data_refresh_window_days",
    "dataSourceId": "data_source_id",
    "databaseEncryption": "database_encryption",
    "databaseType": "database_type",
    "databaseVersion": "database_version",
    "dataflowCustomEndpoint": "dataflow_custom_endpoint",
    "dataprocBetaCustomEndpoint": "dataproc_beta_custom_endpoint",
    "dataprocCustomEndpoint": "dataproc_custom_endpoint",
    "datasetId": "dataset_id",
    "datastoreCustomEndpoint": "datastore_custom_endpoint",
    "deadLetterPolicy": "dead_letter_policy",
    "defaultAcl": "default_acl",
    "defaultAdmissionRule": "default_admission_rule",
    "defaultBucket": "default_bucket",
    "defaultEncryptionConfiguration": "default_encryption_configuration",
    "defaultEventBasedHold": "default_event_based_hold",
    "defaultExpiration": "default_expiration",
    "defaultGameServerConfig": "default_game_server_config",
    "defaultHostname": "default_hostname",
    "defaultLanguageCode": "default_language_code",
    "defaultMaxPodsPerNode": "default_max_pods_per_node",
    "defaultPartitionExpirationMs": "default_partition_expiration_ms",
    "defaultPort": "default_port",
    "defaultResponsePlatforms": "default_response_platforms",
    "defaultRouteAction": "default_route_action",
    "defaultService": "default_service",
    "defaultSnatStatus": "default_snat_status",
    "defaultTableExpirationMs": "default_table_expiration_ms",
    "defaultUrlRedirect": "default_url_redirect",
    "defaultVersion": "default_version",
    "deleteContentsOnDestroy": "delete_contents_on_destroy",
    "deleteDefaultRoutesOnCreate": "delete_default_routes_on_create",
    "deletePolicy": "delete_policy",
    "deleteServiceOnDestroy": "delete_service_on_destroy",
    "deletionProtection": "deletion_protection",
    "deletionTime": "deletion_time",
    "deploymentId": "deployment_id",
    "deploymentManagerCustomEndpoint": "deployment_manager_custom_endpoint",
    "desiredStatus": "desired_status",
    "destRange": "dest_range",
    "destinationDatasetId": "destination_dataset_id",
    "destinationRanges": "destination_ranges",
    "destroyTime": "destroy_time",
    "detailedStatus": "detailed_status",
    "detectMd5hash": "detect_md5hash",
    "deviceName": "device_name",
    "dialogflowCustomEndpoint": "dialogflow_custom_endpoint",
    "dicomStoreId": "dicom_store_id",
    "disableAuth": "disable_auth",
    "disableDependentServices": "disable_dependent_services",
    "disableOnDestroy": "disable_on_destroy",
    "disableReferentialIntegrity": "disable_referential_integrity",
    "disableResourceVersioning": "disable_resource_versioning",
    "diskEncryption": "disk_encryption",
    "diskEncryptionKey": "disk_encryption_key",
    "diskSizeGb": "disk_size_gb",
    "dispatchRules": "dispatch_rules",
    "displayName": "display_name",
    "distributionPolicyZones": "distribution_policy_zones",
    "dnsAddress": "dns_address",
    "dnsBetaCustomEndpoint": "dns_beta_custom_endpoint",
    "dnsCustomEndpoint": "dns_custom_endpoint",
    "dnsName": "dns_name",
    "dnssecConfig": "dnssec_config",
    "domainName": "domain_name",
    "drainNatIps": "drain_nat_ips",
    "driverControlsFilesUri": "driver_controls_files_uri",
    "driverOutputResourceUri": "driver_output_resource_uri",
    "edgeAvailabilityDomain": "edge_availability_domain",
    "enableBatching": "enable_batching",
    "enableBinaryAuthorization": "enable_binary_authorization",
    "enableCdn": "enable_cdn",
    "enableDisplay": "enable_display",
    "enableEmailLinkSignin": "enable_email_link_signin",
    "enableFuzzyExtraction": "enable_fuzzy_extraction",
    "enableHistoryImport": "enable_history_import",
    "enableInboundForwarding": "enable_inbound_forwarding",
    "enableIntranodeVisibility": "enable_intranode_visibility",
    "enableKubernetesAlpha": "enable_kubernetes_alpha",
    "enableLegacyAbac": "enable_legacy_abac",
    "enableLogging": "enable_logging",
    "enableShieldedNodes": "enable_shielded_nodes",
    "enableStackdriverLogging": "enable_stackdriver_logging",
    "enableStackdriverMonitoring": "enable_stackdriver_monitoring",
    "enableTpu": "enable_tpu",
    "enableUpdateCreate": "enable_update_create",
    "enabledFeatures": "enabled_features",
    "encryptionConfiguration": "encryption_configuration",
    "encryptionKeyName": "encryption_key_name",
    "endpointId": "endpoint_id",
    "endpointsApiService": "endpoints_api_service",
    "entityId": "entity_id",
    "entryGroup": "entry_group",
    "entryGroupId": "entry_group_id",
    "entryId": "entry_id",
    "entryPoint": "entry_point",
    "envVariables": "env_variables",
    "environmentVariables": "environment_variables",
    "eventNotificationConfigs": "event_notification_configs",
    "eventTrigger": "event_trigger",
    "eventTypes": "event_types",
    "expirationPolicy": "expiration_policy",
    "expirationTime": "expiration_time",
    "expirationTimeUsec": "expiration_time_usec",
    "expireTime": "expire_time",
    "exportCustomRoutes": "export_custom_routes",
    "exportSubnetRoutesWithPublicIp": "export_subnet_routes_with_public_ip",
    "exportToSecurityCommandCenter": "export_to_security_command_center",
    "externalDataConfiguration": "external_data_configuration",
    "failoverPolicy": "failover_policy",
    "failoverRatio": "failover_ratio",
    "featureSettings": "feature_settings",
    "feedId": "feed_id",
    "feedOutputConfig": "feed_output_config",
    "fhirStoreId": "fhir_store_id",
    "fileShares": "file_shares",
    "filestoreCustomEndpoint": "filestore_custom_endpoint",
    "firebaseCustomEndpoint": "firebase_custom_endpoint",
    "firestoreCustomEndpoint": "firestore_custom_endpoint",
    "firstIpAddress": "first_ip_address",
    "fleetConfigs": "fleet_configs",
    "folderId": "folder_id",
    "followupIntentInfos": "followup_intent_infos",
    "forceDelete": "force_delete",
    "forceDestroy": "force_destroy",
    "forwardingConfig": "forwarding_config",
    "friendlyName": "friendly_name",
    "gameServerConfigOverrides": "game_server_config_overrides",
    "gameServicesCustomEndpoint": "game_services_custom_endpoint",
    "gatewayAddress": "gateway_address",
    "gatewayConfig": "gateway_config",
    "gatewayId": "gateway_id",
    "gatewayIpv4": "gateway_ipv4",
    "gcrDomain": "gcr_domain",
    "gcsFilesetSpec": "gcs_fileset_spec",
    "globalNetworkEndpointGroup": "global_network_endpoint_group",
    "globalPolicyEvaluationMode": "global_policy_evaluation_mode",
    "googleReferenceId": "google_reference_id",
    "groupByEmail": "group_by_email",
    "groupKey": "group_key",
    "groupPlacementPolicy": "group_placement_policy",
    "grpcConfig": "grpc_config",
    "guestAccelerators": "guest_accelerators",
    "guestOsFeatures": "guest_os_features",
    "guestPolicyId": "guest_policy_id",
    "hadoopConfig": "hadoop_config",
    "hasCredential": "has_credential",
    "headerAction": "header_action",
    "healthChecks": "health_checks",
    "healthcareCustomEndpoint": "healthcare_custom_endpoint",
    "healthyThreshold": "healthy_threshold",
    "hiveConfig": "hive_config",
    "hl7V2StoreId": "hl7_v2_store_id",
    "hostProject": "host_project",
    "hostRules": "host_rules",
    "http2HealthCheck": "http2_health_check",
    "httpCheck": "http_check",
    "httpConfig": "http_config",
    "httpEnabledState": "http_enabled_state",
    "httpHealthCheck": "http_health_check",
    "httpTarget": "http_target",
    "httpsHealthCheck": "https_health_check",
    "httpsTriggerUrl": "https_trigger_url",
    "iamCredentialsCustomEndpoint": "iam_credentials_custom_endpoint",
    "iamCustomEndpoint": "iam_custom_endpoint",
    "iamMember": "iam_member",
    "iapCustomEndpoint": "iap_custom_endpoint",
    "icmpIdleTimeoutSec": "icmp_idle_timeout_sec",
    "identityPlatformCustomEndpoint": "identity_platform_custom_endpoint",
    "idpConfig": "idp_config",
    "idpId": "idp_id",
    "ignoreIdleSlots": "ignore_idle_slots",
    "ignoreWarnings": "ignore_warnings",
    "ignoredFiles": "ignored_files",
    "ikeVersion": "ike_version",
    "importCustomRoutes": "import_custom_routes",
    "importJobId": "import_job_id",
    "importMethod": "import_method",
    "importSubnetRoutesWithPublicIp": "import_subnet_routes_with_public_ip",
    "inboundServices": "inbound_services",
    "includeChildren": "include_children",
    "includedFiles": "included_files",
    "indexId": "index_id",
    "ingressSettings": "ingress_settings",
    "initialNodeCount": "initial_node_count",
    "inputContextNames": "input_context_names",
    "installGpuDriver": "install_gpu_driver",
    "instanceClass": "instance_class",
    "instanceDescription": "instance_description",
    "instanceFilter": "instance_filter",
    "instanceGroup": "instance_group",
    "instanceGroupManager": "instance_group_manager",
    "instanceGroupUrls": "instance_group_urls",
    "instanceId": "instance_id",
    "instanceName": "instance_name",
    "instanceOwners": "instance_owners",
    "instanceType": "instance_type",
    "integratedSystem": "integrated_system",
    "interconnectAttachment": "interconnect_attachment",
    "ipAddress": "ip_address",
    "ipAddresses": "ip_addresses",
    "ipAllocationPolicy": "ip_allocation_policy",
    "ipCidrRange": "ip_cidr_range",
    "ipConfiguration": "ip_configuration",
    "ipProtocol": "ip_protocol",
    "ipRange": "ip_range",
    "ipVersion": "ip_version",
    "isCluster": "is_cluster",
    "isFallback": "is_fallback",
    "isMirroringCollector": "is_mirroring_collector",
    "jobId": "job_id",
    "jobTimeoutMs": "job_timeout_ms",
    "jobType": "job_type",
    "keyAlgorithm": "key_algorithm",
    "keyRing": "key_ring",
    "keyRingId": "key_ring_id",
    "keyValue": "key_value",
    "kmsCustomEndpoint": "kms_custom_endpoint",
    "kmsKey": "kms_key",
    "kmsKeyName": "kms_key_name",
    "labelExtractors": "label_extractors",
    "labelFingerprint": "label_fingerprint",
    "lastAttachTimestamp": "last_attach_timestamp",
    "lastConfigAckTime": "last_config_ack_time",
    "lastConfigSendTime": "last_config_send_time",
    "lastDetachTimestamp": "last_detach_timestamp",
    "lastErrorStatus": "last_error_status",
    "lastErrorTime": "last_error_time",
    "lastEventTime": "last_event_time",
    "lastExecuteTime": "last_execute_time",
    "lastHeartbeatTime": "last_heartbeat_time",
    "lastModificationTime": "last_modification_time",
    "lastModifiedTime": "last_modified_time",
    "lastStateTime": "last_state_time",
    "launchStage": "launch_stage",
    "lifecycleRules": "lifecycle_rules",
    "lifecycleState": "lifecycle_state",
    "linkedResource": "linked_resource",
    "listPolicy": "list_policy",
    "livenessCheck": "liveness_check",
    "loadBalancingScheme": "load_balancing_scheme",
    "localTrafficSelectors": "local_traffic_selectors",
    "localityLbPolicy": "locality_lb_policy",
    "locationId": "location_id",
    "logConfig": "log_config",
    "logLevel": "log_level",
    "loggingCustomEndpoint": "logging_custom_endpoint",
    "loggingService": "logging_service",
    "longDescription": "long_description",
    "machineType": "machine_type",
    "maintenancePolicy": "maintenance_policy",
    "managedZone": "managed_zone",
    "managementType": "management_type",
    "manualScaling": "manual_scaling",
    "mapId": "map_id",
    "masterAuth": "master_auth",
    "masterAuthorizedNetworksConfig": "master_authorized_networks_config",
    "masterInstanceName": "master_instance_name",
    "masterVersion": "master_version",
    "matchMode": "match_mode",
    "maxAges": "max_ages",
    "maxInstances": "max_instances",
    "maxPodsPerNode": "max_pods_per_node",
    "maxQps": "max_qps",
    "maxThroughput": "max_throughput",
    "maxVersions": "max_versions",
    "maxWorkers": "max_workers",
    "mediaLink": "media_link",
    "memberKey": "member_key",
    "memcacheCustomEndpoint": "memcache_custom_endpoint",
    "memcacheFullVersion": "memcache_full_version",
    "memcacheNodes": "memcache_nodes",
    "memcacheParameters": "memcache_parameters",
    "memcacheVersion": "memcache_version",
    "memorySizeGb": "memory_size_gb",
    "messageRetentionDuration": "message_retention_duration",
    "messageStoragePolicy": "message_storage_policy",
    "metadataFilters": "metadata_filters",
    "metadataFingerprint": "metadata_fingerprint",
    "metadataStartupScript": "metadata_startup_script",
    "metricDescriptor": "metric_descriptor",
    "metricKind": "metric_kind",
    "migrateTraffic": "migrate_traffic",
    "minCpuPlatform": "min_cpu_platform",
    "minMasterVersion": "min_master_version",
    "minPortsPerVm": "min_ports_per_vm",
    "minThroughput": "min_throughput",
    "minTlsVersion": "min_tls_version",
    "minimalAction": "minimal_action",
    "mirroredResources": "mirrored_resources",
    "mlDisabled": "ml_disabled",
    "mlEngineCustomEndpoint": "ml_engine_custom_endpoint",
    "monitoredResource": "monitored_resource",
    "monitoredResourceTypes": "monitored_resource_types",
    "monitoringCustomEndpoint": "monitoring_custom_endpoint",
    "monitoringService": "monitoring_service",
    "mostDisruptiveAllowedAction": "most_disruptive_allowed_action",
    "mqttConfig": "mqtt_config",
    "mqttEnabledState": "mqtt_enabled_state",
    "multiClusterRoutingUseAny": "multi_cluster_routing_use_any",
    "namePrefix": "name_prefix",
    "nameServers": "name_servers",
    "namedPorts": "named_ports",
    "namespaceId": "namespace_id",
    "natIpAllocateOption": "nat_ip_allocate_option",
    "natIps": "nat_ips",
    "natPolicy": "nat_policy",
    "networkConfig": "network_config",
    "networkEndpointGroup": "network_endpoint_group",
    "networkEndpointType": "network_endpoint_type",
    "networkEndpoints": "network_endpoints",
    "networkInterfaces": "network_interfaces",
    "networkManagementCustomEndpoint": "network_management_custom_endpoint",
    "networkPolicy": "network_policy",
    "networkTier": "network_tier",
    "networkingMode": "networking_mode",
    "nextHopGateway": "next_hop_gateway",
    "nextHopIlb": "next_hop_ilb",
    "nextHopInstance": "next_hop_instance",
    "nextHopInstanceZone": "next_hop_instance_zone",
    "nextHopIp": "next_hop_ip",
    "nextHopNetwork": "next_hop_network",
    "nextHopVpnTunnel": "next_hop_vpn_tunnel",
    "noProxyAccess": "no_proxy_access",
    "noPublicIp": "no_public_ip",
    "noRemoveDataDisk": "no_remove_data_disk",
    "nobuildFilesRegex": "nobuild_files_regex",
    "nodeAffinityLabels": "node_affinity_labels",
    "nodeConfig": "node_config",
    "nodeCount": "node_count",
    "nodeLocations": "node_locations",
    "nodePools": "node_pools",
    "nodeTemplate": "node_template",
    "nodeType": "node_type",
    "nodeTypeFlexibility": "node_type_flexibility",
    "nodeVersion": "node_version",
    "noopOnDestroy": "noop_on_destroy",
    "noteName": "note_name",
    "notebooksCustomEndpoint": "notebooks_custom_endpoint",
    "notificationChannels": "notification_channels",
    "notificationConfig": "notification_config",
    "notificationConfigs": "notification_configs",
    "notificationId": "notification_id",
    "numBytes": "num_bytes",
    "numId": "num_id",
    "numLongTermBytes": "num_long_term_bytes",
    "numNodes": "num_nodes",
    "numRows": "num_rows",
    "objectNamePrefix": "object_name_prefix",
    "onDelete": "on_delete",
    "oneTimeSchedule": "one_time_schedule",
    "onlinePredictionConsoleLogging": "online_prediction_console_logging",
    "onlinePredictionLogging": "online_prediction_logging",
    "openapiConfig": "openapi_config",
    "orgId": "org_id",
    "orgInternalOnly": "org_internal_only",
    "osConfigCustomEndpoint": "os_config_custom_endpoint",
    "osLoginCustomEndpoint": "os_login_custom_endpoint",
    "outlierDetection": "outlier_detection",
    "outputName": "output_name",
    "overrideStrategy": "override_strategy",
    "overrideValue": "override_value",
    "packageRepositories": "package_repositories",
    "pairingKey": "pairing_key",
    "parentFollowupIntentName": "parent_followup_intent_name",
    "parentName": "parent_name",
    "parserConfig": "parser_config",
    "partnerAsn": "partner_asn",
    "patchConfig": "patch_config",
    "patchDeploymentId": "patch_deployment_id",
    "pathMatchers": "path_matchers",
    "payloadFormat": "payload_format",
    "peerAsn": "peer_asn",
    "peerExternalGateway": "peer_external_gateway",
    "peerExternalGatewayInterface": "peer_external_gateway_interface",
    "peerGcpGateway": "peer_gcp_gateway",
    "peerIp": "peer_ip",
    "peerIpAddress": "peer_ip_address",
    "peerNetwork": "peer_network",
    "peeringConfig": "peering_config",
    "perimeterName": "perimeter_name",
    "perimeterType": "perimeter_type",
    "persistenceIamIdentity": "persistence_iam_identity",
    "physicalBlockSizeBytes": "physical_block_size_bytes",
    "pigConfig": "pig_config",
    "podSecurityPolicyConfig": "pod_security_policy_config",
    "policyData": "policy_data",
    "policyId": "policy_id",
    "portName": "port_name",
    "portRange": "port_range",
    "postStartupScript": "post_startup_script",
    "predefinedAcl": "predefined_acl",
    "preferredMemberKey": "preferred_member_key",
    "prefixLength": "prefix_length",
    "preservedState": "preserved_state",
    "privateClusterConfig": "private_cluster_config",
    "privateInstance": "private_instance",
    "privateInterconnectInfo": "private_interconnect_info",
    "privateIpAddress": "private_ip_address",
    "privateIpGoogleAccess": "private_ip_google_access",
    "privateKey": "private_key",
    "privateKeyType": "private_key_type",
    "privateVisibilityConfig": "private_visibility_config",
    "projectId": "project_id",
    "projectNumber": "project_number",
    "projectTeam": "project_team",
    "protectionLevel": "protection_level",
    "protocOutputBase64": "protoc_output_base64",
    "proxyHeader": "proxy_header",
    "proxyId": "proxy_id",
    "proxyUri": "proxy_uri",
    "publicIpAddress": "public_ip_address",
    "publicKey": "public_key",
    "publicKeyData": "public_key_data",
    "publicKeyType": "public_key_type",
    "pubsubConfigs": "pubsub_configs",
    "pubsubCustomEndpoint": "pubsub_custom_endpoint",
    "pubsubTarget": "pubsub_target",
    "pubsubTopicName": "pubsub_topic_name",
    "pushConfig": "push_config",
    "pysparkConfig": "pyspark_config",
    "queryScope": "query_scope",
    "quicOverride": "quic_override",
    "rangePartitioning": "range_partitioning",
    "rateLimits": "rate_limits",
    "rawDisk": "raw_disk",
    "readinessCheck": "readiness_check",
    "realmId": "realm_id",
    "recurringSchedule": "recurring_schedule",
    "redisConfigs": "redis_configs",
    "redisCustomEndpoint": "redis_custom_endpoint",
    "redisVersion": "redis_version",
    "redundancyType": "redundancy_type",
    "regionInstanceGroupManager": "region_instance_group_manager",
    "relatedNoteNames": "related_note_names",
    "relatedProjects": "related_projects",
    "relatedUrls": "related_urls",
    "releaseChannel": "release_channel",
    "remoteTrafficSelectors": "remote_traffic_selectors",
    "removeDefaultNodePool": "remove_default_node_pool",
    "removeInstanceStateOnDestroy": "remove_instance_state_on_destroy",
    "replicaConfiguration": "replica_configuration",
    "replicaZones": "replica_zones",
    "repositoryId": "repository_id",
    "requestBasedSli": "request_based_sli",
    "requestPath": "request_path",
    "requestTimeout": "request_timeout",
    "requesterPays": "requester_pays",
    "reservedIpRange": "reserved_ip_range",
    "reservedPeeringRanges": "reserved_peering_ranges",
    "resetContexts": "reset_contexts",
    "resourceGroup": "resource_group",
    "resourceLabels": "resource_labels",
    "resourceManagerCustomEndpoint": "resource_manager_custom_endpoint",
    "resourceManagerV2beta1CustomEndpoint": "resource_manager_v2beta1_custom_endpoint",
    "resourcePolicies": "resource_policies",
    "resourceRecords": "resource_records",
    "resourceUri": "resource_uri",
    "resourceUsageExportConfig": "resource_usage_export_config",
    "restorePolicy": "restore_policy",
    "retainAckedMessages": "retain_acked_messages",
    "retentionDays": "retention_days",
    "retentionPolicy": "retention_policy",
    "retryConfig": "retry_config",
    "reverseLookup": "reverse_lookup",
    "roleEntities": "role_entities",
    "roleId": "role_id",
    "rollingPeriodDays": "rolling_period_days",
    "rootFollowupIntentName": "root_followup_intent_name",
    "rootPassword": "root_password",
    "rotationPeriod": "rotation_period",
    "routingMode": "routing_mode",
    "runtimeApiVersion": "runtime_api_version",
    "runtimeChannel": "runtime_channel",
    "runtimeConfigCustomEndpoint": "runtime_config_custom_endpoint",
    "runtimeMainExecutablePath": "runtime_main_executable_path",
    "runtimeconfigCustomEndpoint": "runtimeconfig_custom_endpoint",
    "scalingConfigs": "scaling_configs",
    "schedulingConfig": "scheduling_config",
    "scratchDisks": "scratch_disks",
    "secondaryIpRanges": "secondary_ip_ranges",
    "secondaryWorkerConfig": "secondary_worker_config",
    "secretData": "secret_data",
    "secretId": "secret_id",
    "secretManagerCustomEndpoint": "secret_manager_custom_endpoint",
    "securityCenterCustomEndpoint": "security_center_custom_endpoint",
    "securityPolicy": "security_policy",
    "securityScannerCustomEndpoint": "security_scanner_custom_endpoint",
    "selectedRegions": "selected_regions",
    "selfLink": "self_link",
    "sendAfter": "send_after",
    "sensitiveLabels": "sensitive_labels",
    "serverBinding": "server_binding",
    "serverCaCert": "server_ca_cert",
    "serviceAccount": "service_account",
    "serviceAccountEmail": "service_account_email",
    "serviceAccountEmailAddress": "service_account_email_address",
    "serviceAccountId": "service_account_id",
    "serviceAccountName": "service_account_name",
    "serviceDirectoryConfig": "service_directory_config",
    "serviceDirectoryCustomEndpoint": "service_directory_custom_endpoint",
    "serviceEndpoint": "service_endpoint",
    "serviceId": "service_id",
    "serviceLabel": "service_label",
    "serviceManagementCustomEndpoint": "service_management_custom_endpoint",
    "serviceName": "service_name",
    "serviceNetworkingCustomEndpoint": "service_networking_custom_endpoint",
    "serviceProject": "service_project",
    "serviceUsageCustomEndpoint": "service_usage_custom_endpoint",
    "servicesIpv4Cidr": "services_ipv4_cidr",
    "servingStatus": "serving_status",
    "sessionAffinity": "session_affinity",
    "sha1Fingerprint": "sha1_fingerprint",
    "sharedSecret": "shared_secret",
    "sharedSecretHash": "shared_secret_hash",
    "shieldedInstanceConfig": "shielded_instance_config",
    "shortDescription": "short_description",
    "singleClusterRouting": "single_cluster_routing",
    "skipDelete": "skip_delete",
    "sloId": "slo_id",
    "slotCapacity": "slot_capacity",
    "snapshotEncryptionKey": "snapshot_encryption_key",
    "snapshotId": "snapshot_id",
    "snapshotSchedulePolicy": "snapshot_schedule_policy",
    "sourceArchiveBucket": "source_archive_bucket",
    "sourceArchiveObject": "source_archive_object",
    "sourceDisk": "source_disk",
    "sourceDiskEncryptionKey": "source_disk_encryption_key",
    "sourceDiskLink": "source_disk_link",
    "sourceImage": "source_image",
    "sourceImageEncryptionKey": "source_image_encryption_key",
    "sourceImageId": "source_image_id",
    "sourceInstance": "source_instance",
    "sourceInstanceTemplate": "source_instance_template",
    "sourceRange": "source_range",
    "sourceRanges": "source_ranges",
    "sourceRepoCustomEndpoint": "source_repo_custom_endpoint",
    "sourceRepository": "source_repository",
    "sourceServiceAccounts": "source_service_accounts",
    "sourceSnapshot": "source_snapshot",
    "sourceSnapshotEncryptionKey": "source_snapshot_encryption_key",
    "sourceSnapshotId": "source_snapshot_id",
    "sourceSubnetworkIpRangesToNat": "source_subnetwork_ip_ranges_to_nat",
    "sourceTags": "source_tags",
    "spConfig": "sp_config",
    "spannerCustomEndpoint": "spanner_custom_endpoint",
    "sparkConfig": "spark_config",
    "sparksqlConfig": "sparksql_config",
    "specialGroup": "special_group",
    "specificReservation": "specific_reservation",
    "specificReservationRequired": "specific_reservation_required",
    "splitKeys": "split_keys",
    "sqlCustomEndpoint": "sql_custom_endpoint",
    "sslCertificates": "ssl_certificates",
    "sslHealthCheck": "ssl_health_check",
    "sslPolicy": "ssl_policy",
    "sslSettings": "ssl_settings",
    "startingUrls": "starting_urls",
    "stateDetails": "state_details",
    "stateMessage": "state_message",
    "stateNotificationConfig": "state_notification_config",
    "statefulDisks": "stateful_disks",
    "storageBytes": "storage_bytes",
    "storageClass": "storage_class",
    "storageCustomEndpoint": "storage_custom_endpoint",
    "storageTransferCustomEndpoint": "storage_transfer_custom_endpoint",
    "streamConfigs": "stream_configs",
    "subjectAlternativeNames": "subject_alternative_names",
    "supportEmail": "support_email",
    "supportedLanguageCodes": "supported_language_codes",
    "tableId": "table_id",
    "tagTemplateId": "tag_template_id",
    "tagsFingerprint": "tags_fingerprint",
    "targetPlatforms": "target_platforms",
    "targetPools": "target_pools",
    "targetResources": "target_resources",
    "targetServiceAccounts": "target_service_accounts",
    "targetSize": "target_size",
    "targetTags": "target_tags",
    "targetVpnGateway": "target_vpn_gateway",
    "tcpCheck": "tcp_check",
    "tcpEstablishedIdleTimeoutSec": "tcp_established_idle_timeout_sec",
    "tcpHealthCheck": "tcp_health_check",
    "tcpTransitoryIdleTimeoutSec": "tcp_transitory_idle_timeout_sec",
    "tempGcsLocation": "temp_gcs_location",
    "templateDisplayname": "template_displayname",
    "templateGcsPath": "template_gcs_path",
    "tensorflowVersion": "tensorflow_version",
    "thresholdRules": "threshold_rules",
    "timeCreated": "time_created",
    "timePartitioning": "time_partitioning",
    "timeZone": "time_zone",
    "timeoutSec": "timeout_sec",
    "tpuCustomEndpoint": "tpu_custom_endpoint",
    "tpuIpv4CidrBlock": "tpu_ipv4_cidr_block",
    "transferSpec": "transfer_spec",
    "triggerHttp": "trigger_http",
    "triggerId": "trigger_id",
    "triggerTemplate": "trigger_template",
    "tunnelId": "tunnel_id",
    "udpIdleTimeoutSec": "udp_idle_timeout_sec",
    "unhealthyThreshold": "unhealthy_threshold",
    "uniqueId": "unique_id",
    "uniqueWriterIdentity": "unique_writer_identity",
    "updatePolicy": "update_policy",
    "updateTime": "update_time",
    "upgradeSettings": "upgrade_settings",
    "uptimeCheckId": "uptime_check_id",
    "urlDispatchRules": "url_dispatch_rules",
    "urlMap": "url_map",
    "useExplicitDryRunSpec": "use_explicit_dry_run_spec",
    "userAgent": "user_agent",
    "userByEmail": "user_by_email",
    "userEmail": "user_email",
    "userLabels": "user_labels",
    "userProjectOverride": "user_project_override",
    "userSpecifiedSystem": "user_specified_system",
    "userSpecifiedType": "user_specified_type",
    "validAfter": "valid_after",
    "validBefore": "valid_before",
    "valueExtractor": "value_extractor",
    "valueType": "value_type",
    "verificationStatus": "verification_status",
    "versionId": "version_id",
    "versionTemplate": "version_template",
    "verticalPodAutoscaling": "vertical_pod_autoscaling",
    "vlanTag8021q": "vlan_tag8021q",
    "vmImage": "vm_image",
    "vpcAccessConnector": "vpc_access_connector",
    "vpcAccessCustomEndpoint": "vpc_access_custom_endpoint",
    "vpcConnector": "vpc_connector",
    "vpcConnectorEgressSettings": "vpc_connector_egress_settings",
    "vpnGateway": "vpn_gateway",
    "vpnGatewayInterface": "vpn_gateway_interface",
    "vpnInterfaces": "vpn_interfaces",
    "vpnTunnel": "vpn_tunnel",
    "waitForInstances": "wait_for_instances",
    "webBackendService": "web_backend_service",
    "webhookState": "webhook_state",
    "windowsBasedSli": "windows_based_sli",
    "workerConfig": "worker_config",
    "workloadIdentityConfig": "workload_identity_config",
    "writerIdentity": "writer_identity",
}



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Dict, List, Mapping, Optional, Tuple, Union
from .. import _utilities, _tables

__all__ = ['GameServerDeployment']


class GameServerDeployment(pulumi.CustomResource):
    def __init__(__self__,
                 resource_name,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 deployment_id: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 labels: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 location: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 __props__=None,
                 __name__=None,
                 __opts__=None):
        """
        A game server deployment resource.

        To get more information about GameServerDeployment, see:

        * [API documentation](https://cloud.google.com/game-servers/docs/reference/rest/v1beta/projects.locations.gameServerDeployments)
        * How-to Guides
            * [Official Documentation](https://cloud.google.com/game-servers/docs)

        ## Example Usage

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] deployment_id: A unique id for the deployment.
        :param pulumi.Input[str] description: Human readable description of the game server deployment.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] labels: The labels associated with this game server deployment. Each label is a
               key-value pair.
        :param pulumi.Input[str] location: Location of the Deployment.
        :param pulumi.Input[str] project: The ID of the project in which the resource belongs.
               If it is not provided, the provider project is used.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = _utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            if deployment_id is None:
                raise TypeError("Missing required property 'deployment_id'")
            __props__['deployment_id'] = deployment_id
            __props__['description'] = description
            __props__['labels'] = labels
            __props__['location'] = location
            __props__['project'] = project
            __props__['name'] = None
        super(GameServerDeployment, __self__).__init__(
            'gcp:gameservices/gameServerDeployment:GameServerDeployment',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            deployment_id: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            labels: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            location: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            project: Optional[pulumi.Input[str]] = None) -> 'GameServerDeployment':
        """
        Get an existing GameServerDeployment resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] deployment_id: A unique id for the deployment.
        :param pulumi.Input[str] description: Human readable description of the game server deployment.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] labels: The labels associated with this game server deployment. Each label is a
               key-value pair.
        :param pulumi.Input[str] location: Location of the Deployment.
        :param pulumi.Input[str] name: The resource id of the game server deployment, eg:
               'projects/{project_id}/locations/{location}/gameServerDeployments/{deployment_id}'. For example,
               'projects/my-project/locations/{location}/gameServerDeployments/my-deployment'.
        :param pulumi.Input[str] project: The ID of the project in which the resource belongs.
               If it is not provided, the provider project is used.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["deployment_id"] = deployment_id
        __props__["description"] = description
        __props__["labels"] = labels
        __props__["location"] = location
        __props__["name"] = name
        __props__["project"] = project
        return GameServerDeployment(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="deploymentId")
    def deployment_id(self) -> str:
        """
        A unique id for the deployment.
        """
        return pulumi.get(self, "deployment_id")

    @property
    @pulumi.getter
    def description(self) -> Optional[str]:
        """
        Human readable description of the game server deployment.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def labels(self) -> Optional[Mapping[str, str]]:
        """
        The labels associated with this game server deployment. Each label is a
        key-value pair.
        """
        return pulumi.get(self, "labels")

    @property
    @pulumi.getter
    def location(self) -> Optional[str]:
        """
        Location of the Deployment.
        """
        return pulumi.get(self, "location")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The resource id of the game server deployment, eg:
        'projects/{project_id}/locations/{location}/gameServerDeployments/{deployment_id}'. For example,
        'projects/my-project/locations/{location}/gameServerDeployments/my-deployment'.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def project(self) -> str:
        """
        The ID of the project in which the resource belongs.
        If it is not provided, the provider project is used.
        """
        return pulumi.get(self, "project")

    def translate_output_property(self, prop):
        return _tables.CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return _tables.SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Dict, List, Mapping, Optional, Tuple, Union
from .. import _utilities, _tables

__all__ = ['BackendBucketSignedUrlKey']


class BackendBucketSignedUrlKey(pulumi.CustomResource):
    def __init__(__self__,
                 resource_name,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 backend_bucket: Optional[pulumi.Input[str]] = None,
                 key_value: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 __props__=None,
                 __name__=None,
                 __opts__=None):
        """
        A key for signing Cloud CDN signed URLs for BackendBuckets.

        To get more information about BackendBucketSignedUrlKey, see:

        * [API documentation](https://cloud.google.com/compute/docs/reference/rest/v1/backendBuckets)
        * How-to Guides
            * [Using Signed URLs](https://cloud.google.com/cdn/docs/using-signed-urls/)

        > **Warning:** All arguments including `key_value` will be stored in the raw
        state as plain-text.

        ## Example Usage

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] backend_bucket: The backend bucket this signed URL key belongs.
        :param pulumi.Input[str] key_value: 128-bit key value used for signing the URL. The key value must be a
               valid RFC 4648 Section 5 base64url encoded string.
               **Note**: This property is sensitive and will not be displayed in the plan.
        :param pulumi.Input[str] name: Name of the signed URL key.
        :param pulumi.Input[str] project: The ID of the project in which the resource belongs.
               If it is not provided, the provider project is used.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = _utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            if backend_bucket is None:
                raise TypeError("Missing required property 'backend_bucket'")
            __props__['backend_bucket'] = backend_bucket
            if key_value is None:
                raise TypeError("Missing required property 'key_value'")
            __props__['key_value'] = key_value
            __props__['name'] = name
            __props__['project'] = project
        super(BackendBucketSignedUrlKey, __self__).__init__(
            'gcp:compute/backendBucketSignedUrlKey:BackendBucketSignedUrlKey',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            backend_bucket: Optional[pulumi.Input[str]] = None,
            key_value: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            project: Optional[pulumi.Input[str]] = None) -> 'BackendBucketSignedUrlKey':
        """
        Get an existing BackendBucketSignedUrlKey resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] backend_bucket: The backend bucket this signed URL key belongs.
        :param pulumi.Input[str] key_value: 128-bit key value used for signing the URL. The key value must be a
               valid RFC 4648 Section 5 base64url encoded string.
               **Note**: This property is sensitive and will not be displayed in the plan.
        :param pulumi.Input[str] name: Name of the signed URL key.
        :param pulumi.Input[str] project: The ID of the project in which the resource belongs.
               If it is not provided, the provider project is used.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["backend_bucket"] = backend_bucket
        __props__["key_value"] = key_value
        __props__["name"] = name
        __props__["project"] = project
        return BackendBucketSignedUrlKey(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="backendBucket")
    def backend_bucket(self) -> str:
        """
        The backend bucket this signed URL key belongs.
        """
        return pulumi.get(self, "backend_bucket")

    @property
    @pulumi.getter(name="keyValue")
    def key_value(self) -> str:
        """
        128-bit key value used for signing the URL. The key value must be a
        valid RFC 4648 Section 5 base64url encoded string.
        **Note**: This property is sensitive and will not be displayed in the plan.
        """
        return pulumi.get(self, "key_value")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        Name of the signed URL key.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def project(self) -> str:
        """
        The ID of the project in which the resource belongs.
        If it is not provided, the provider project is used.
        """
        return pulumi.get(self, "project")

    def translate_output_property(self, prop):
        return _tables.CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return _tables.SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop

